@@ -5,11 +5,7 @@
  *          Marek Senderski  <msend@o2.pl>
  *
  * released under GNU GPL v2 or later licence
- * $Id: AddrAddr.h,v 1.4 2004/06/20 19:36:46 thomson Exp $
- *
- * $Log: AddrAddr.h,v $
- * Revision 1.4  2004/06/20 19:36:46  thomson
- * Minor fixes.
+ * $Id: AddrAddr.h,v 1.8 2007-04-22 21:19:26 thomson Exp $
  *
  */
 
@@ -29,6 +25,7 @@ class TAddrAddr
   public:
 
     TAddrAddr(SmartPtr<TIPv6Addr> addr, long pref, long valid);
+    TAddrAddr(SmartPtr<TIPv6Addr> addr, long pref, long valid, int prefix);
 
     // return address in packed format (char[16])
     SmartPtr<TIPv6Addr> get();
@@ -40,6 +37,7 @@ class TAddrAddr
     void setPref(unsigned long pref);
     void setValid(unsigned long valid);
     unsigned long getValidTimeout();
+    int getPrefix();
 
     // timestamp
     long getTimestamp();
@@ -50,15 +48,13 @@ class TAddrAddr
     enum ETentative getTentative();
     void setTentative(enum ETentative state);
 
-  private:
+  protected:
     enum ETentative Tentative;
 
-    long Prefered;
-    long Valid;
+    unsigned long Prefered;
+    unsigned long Valid;
     SmartPtr<TIPv6Addr> Addr;
-    long Timestamp;
+    unsigned long Timestamp;
+    int Prefix;
 };
-
-
 #endif
-
