@@ -4,10 +4,11 @@
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>
  *          Marek Senderski <msend@o2.pl>
  * changes: Krzysztof Wnuk <keczi@poczta.onet.pl>
+ *          Micha Kowalczuk <michal@kowalczuk.eu>
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: AddrMgr.cpp,v 1.29 2007-05-04 17:19:16 thomson Exp $
+ * $Id: AddrMgr.cpp,v 1.31 2008-02-25 17:49:06 thomson Exp $
  *
  */
 
@@ -67,7 +68,7 @@ SmartPtr<TAddrClient> TAddrMgr::getClient()
     return ClntsLst.get();
 }
 
-SmartPtr<TAddrClient> TAddrMgr::getClient(SmartPtr<TDUID> duid)
+SPtr<TAddrClient> TAddrMgr::getClient(SmartPtr<TDUID> duid)
 {
     SmartPtr<TAddrClient> ptr;
     ClntsLst.first();
@@ -79,6 +80,35 @@ SmartPtr<TAddrClient> TAddrMgr::getClient(SmartPtr<TDUID> duid)
     return SmartPtr<TAddrClient>();
 }
 
+SmartPtr<TAddrClient> TAddrMgr::getClient(uint32_t SPI)
+{
+    SmartPtr<TAddrClient> ptr;
+    ClntsLst.first();
+    while (ptr = ClntsLst.get() ) 
+    {
+        if ( ptr->getSPI() == SPI )
+            return ptr;
+    }
+    return SmartPtr<TAddrClient>();
+}
+
+SPtr<TAddrClient> TAddrMgr::getClient(SPtr<TIPv6Addr> leasedAddr)
+{
+    SPtr<TAddrClient> cli;
+    ClntsLst.first();
+    while (cli = ClntsLst.get() ) 
+    {
+	SPtr<TAddrIA> ia;
+	cli->firstIA();
+	while (ia = cli->getIA()) {
+	    if ( ia->getAddr(leasedAddr) )
+		return cli;
+	}
+    }
+
+    return 0;
+}
+
 int TAddrMgr::countClient()
 {
     return ClntsLst.count();
