@@ -36,6 +36,8 @@ class TAddrMgr
     void firstClient();
     SmartPtr<TAddrClient> getClient();
     SmartPtr<TAddrClient> getClient(SmartPtr<TDUID> duid);
+    SmartPtr<TAddrClient> getClient(uint32_t SPI);
+    SPtr<TAddrClient> getClient(SPtr<TIPv6Addr> leasedAddr);
     int countClient();
     bool delClient(SmartPtr<TDUID> duid);
 
