@@ -6,15 +6,10 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: ClntCfgIA.h,v 1.5 2004/10/25 20:45:52 thomson Exp $
- *
- * $Log: ClntCfgIA.h,v $
- * Revision 1.5  2004/10/25 20:45:52  thomson
- * Option support, parsers rewritten. ClntIfaceMgr now handles options.
- *
- *
+ * $Id: ClntCfgIA.h,v 1.8 2007-04-22 21:19:27 thomson Exp $
  */
 
+class TClntCfgIA;
 #ifndef CLNTCFGIA_H
 #define CLNTCFGIA_H
 
@@ -29,7 +24,7 @@ using namespace std;
 
 class TClntCfgIA
 {
-	friend std::ostream& operator<<(std::ostream& out,TClntCfgIA& group);
+    friend std::ostream& operator<<(std::ostream& out,TClntCfgIA& group);
  public:
     long getIAID();
     void setIAID(long iaid);
@@ -44,19 +39,23 @@ class TClntCfgIA
     long countAddr();
     void addAddr(SmartPtr<TClntCfgAddr> addr);
 
-    TClntCfgIA(long IAID);
+    TClntCfgIA();
     TClntCfgIA(SmartPtr<TClntCfgIA> right, long iAID);
 
     void setState(enum EState state);
     enum EState getState();
-
+    bool getAddrParams();
+    
   private:
     unsigned long IAID;
     unsigned long T1;
     unsigned long T2;
     
     EState State;	
-    TContainer< SmartPtr<TClntCfgAddr> > ClntCfgAddrLst;
+    List(TClntCfgAddr) ClntCfgAddrLst;
+
+    bool AddrParams;
 };
 
 #endif 
+
