@@ -4,9 +4,11 @@
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>                           
  *          Marek Senderski <msend@o2.pl>                                    
  * changes: Krzysztof Wnuk <keczi@poczta.onet.pl>                                                                         
+ *          Michal Kowalczuk <michal@kowalczuk.eu>
+ * 
  * released under GNU GPL v2 or later licence                                
  *                                                                           
- * $Id: ClntCfgMgr.cpp,v 1.53 2007-05-05 12:31:58 thomson Exp $
+ * $Id: ClntCfgMgr.cpp,v 1.58 2008-06-02 00:15:00 thomson Exp $
  *
  */
 
@@ -54,7 +56,11 @@ TClntCfgMgr::TClntCfgMgr(SmartPtr<TClntIfaceMgr> ClntIfaceMgr,
 	return;
     }
     this->dump();
-    
+
+#ifndef MOD_DISABLE_AUTH
+    AuthKeys = new KeyList();
+#endif
+
     IsDone = false;
 }
 
@@ -517,6 +523,10 @@ bool TClntCfgMgr::setGlobalOptions(ClntParser * parser)
     this->InsistMode     = opt->getInsistMode();   // should the client insist on receiving all options
                                                    // i.e. sending INF-REQUEST if REQUEST did not grant required opts
     this->InactiveMode   = opt->getInactiveMode(); // should the client accept not ready interfaces?
+
+    this->FQDNFlagS      = opt->getFQDNFlagS();
+
+    this->MappingPrefix  = opt->getMappingPrefix(); // experimental feature
     
     // user has specified DUID type, just in case if new DUID will be generated
     if (parser->DUIDType != DUID_TYPE_NOT_DEFINED) {
@@ -526,9 +536,26 @@ bool TClntCfgMgr::setGlobalOptions(ClntParser * parser)
       this->DUIDEnterpriseID     = parser->DUIDEnterpriseID;
     }
 
+#ifndef MOD_DISABLE_AUTH
+    this->AuthEnabled = opt->getAuthEnabled();
+    if (this->AuthEnabled)
+        this->AuthAcceptMethods = opt->getAuthAcceptMethods();
+    else
+        this->AuthAcceptMethods.clear();
+    this->AAASPI = getAAASPIfromFile();
+#endif
+
     return true;
 }
 
+void TClntCfgMgr::setDigest(DigestTypes type)
+{
+    if (type >= DIGEST_INVALID)
+        this->Digest = DIGEST_NONE;
+    else
+        this->Digest = type;
+}
+
 DigestTypes TClntCfgMgr::getDigest()
 {
     return this->Digest;
@@ -553,6 +580,22 @@ bool TClntCfgMgr::inactiveMode()
     return InactiveMode;
 }
 
+bool TClntCfgMgr::addInfRefreshTime()
+{
+    /* this can be considered a workaround, but for now ask for inf-refresh-time 
+       only when running in stateless mode */
+
+    // are there any stateful interfaces?
+    SmartPtr<TClntCfgIface> ptr;
+    firstIface();
+    while ( ptr = getIface() ) {
+        if (!ptr->stateless())
+	    return false;
+    }
+
+    return true;
+}
+
 bool TClntCfgMgr::insistMode()
 {
     return InsistMode;
@@ -599,6 +642,33 @@ SPtr<TClntCfgIface> TClntCfgMgr::checkInactiveIfaces()
     return 0;
 }
 
+#ifndef MOD_DISABLE_AUTH
+uint32_t TClntCfgMgr::getAAASPI() {
+    return AAASPI;
+}
+
+List(DigestTypes) TClntCfgMgr::getAuthAcceptMethods()
+{
+    return AuthAcceptMethods;
+}
+
+bool TClntCfgMgr::getAuthEnabled()
+{
+    return AuthEnabled;
+}
+#endif
+
+bool TClntCfgMgr::getFQDNFlagS()
+{
+    return FQDNFlagS;
+}
+
+bool TClntCfgMgr::getMappingPrefix()
+{
+    return MappingPrefix;
+}
+
+
 TClntCfgMgr::~TClntCfgMgr() {
     Log(Debug) << "ClntCfgMgr cleanup." << LogEnd;
 }
@@ -613,6 +683,7 @@ ostream & operator<<(ostream &strum, TClntCfgMgr &x)
     strum << "  <AnonInfRequest>" << (x.anonInfRequest()?1:0) << "</AnonInfRequest>" << endl;
     strum << "  <InsistMode>" << (x.InsistMode?1:0) << "</InsistMode>" << endl;
     strum << "  <InactiveMode>" << (x.InactiveMode?1:0) << "</InactiveMode>" << endl;
+    strum << "  <FQDNFlagS>" << (x.FQDNFlagS?1:0) << "</FQDNFlagS>" << endl;
     strum << "  <digest>";
     switch (x.getDigest()) {
     case DIGEST_NONE:
