@@ -4,9 +4,11 @@
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>                           
  *          Marek Senderski <msend@o2.pl>                                    
  * changes: Krzysztof WNuk <keczi@poczta.onet.pl>                                                                         
+ *          Michal Kowalczuk <michal@kowalczuk.eu>
+ *
  * released under GNU GPL v2 or later licence                                
  *                                                                           
- * $Id: ClntCfgMgr.h,v 1.19 2007-04-01 04:53:17 thomson Exp $
+ * $Id: ClntCfgMgr.h,v 1.24 2008-06-02 00:15:00 thomson Exp $
  */
 
 class TClntCfgMgr;
@@ -24,6 +26,10 @@ class ClntParser;
 #include "ClntCfgPD.h"
 #include "CfgMgr.h"
 
+#ifndef MOD_DISABLE_AUTH
+#include "KeyList.h"
+#endif
+
 class TClntCfgMgr : public TCfgMgr
 {
     friend ostream & operator<<(ostream &strum, TClntCfgMgr &x);
@@ -52,16 +58,29 @@ class TClntCfgMgr : public TCfgMgr
     bool isDone();
 
     DigestTypes getDigest();
+    void setDigest(DigestTypes value);
     string getScriptsDir();
 
     bool anonInfRequest();
     bool insistMode();
     bool inactiveMode();
+    bool addInfRefreshTime();
 
     int inactiveIfacesCnt();
     SPtr<TClntCfgIface> checkInactiveIfaces();
     bool openSocket(SPtr<TClntCfgIface> iface);
 
+#ifndef MOD_DISABLE_AUTH
+    // Authorization
+    uint32_t getAAASPI();
+    List(DigestTypes) getAuthAcceptMethods();
+    bool getAuthEnabled();
+    SmartPtr<KeyList> AuthKeys;
+#endif
+
+    bool getFQDNFlagS();
+    bool getMappingPrefix();
+
 private:
     bool setGlobalOptions(ClntParser * parser);
     bool validateConfig();
@@ -81,6 +100,16 @@ private:
     bool AnonInfRequest;
     bool InsistMode;
     bool InactiveMode;
+
+
+#ifndef MOD_DISABLE_AUTH
+    bool AuthEnabled;
+    List(DigestTypes) AuthAcceptMethods;
+    uint32_t AAASPI;
+#endif
+
+    bool FQDNFlagS; // S bit in the FQDN option
+    bool MappingPrefix;
 };
 
 typedef bool HardcodedCfgFunc(TClntCfgMgr *cfgMgr, string params);
