@@ -6,13 +6,14 @@
  *                                                                           
  * released under GNU GPL v2 or later licence                                
  *                                                                           
- * $Id: ClntParsGlobalOpt.cpp,v 1.11 2007-04-22 21:19:27 thomson Exp $
+ * $Id: ClntParsGlobalOpt.cpp,v 1.15 2008-06-01 23:15:34 thomson Exp $
  *
  */
 
 #include "ClntParsGlobalOpt.h"
 #include "Portable.h"
 #include "DHCPConst.h"
+#include "Logger.h"
 
 TClntParsGlobalOpt::TClntParsGlobalOpt() 
     :TClntParsIfaceOpt() {
@@ -23,7 +24,12 @@ TClntParsGlobalOpt::TClntParsGlobalOpt()
     this->AnonInfRequest = false;
     this->InactiveMode   = false;
     this->InsistMode     = false;
+    this->FQDNFlagS      = false;
     this->Experimental   = false;
+    this->ExperimentalMappingPrefix = false;
+
+    this->AuthEnabled    = false;
+    this->AuthAcceptMethods.clear();
 }
 
 TClntParsGlobalOpt::~TClntParsGlobalOpt() {
@@ -98,3 +104,46 @@ bool TClntParsGlobalOpt::getExperimental()
 {
     return Experimental;
 }
+
+void TClntParsGlobalOpt::setAuthAcceptMethods(List(DigestTypes) lst)
+{
+    AuthAcceptMethods = lst;
+    Log(Debug) << "AUTH: " << lst.count() << " method(s) accepted." << LogEnd;
+}
+
+List(DigestTypes) TClntParsGlobalOpt::getAuthAcceptMethods()
+{
+    return AuthAcceptMethods;
+}
+
+void TClntParsGlobalOpt::setFQDNFlagS(bool s)
+{
+    FQDNFlagS = s;
+}
+
+bool TClntParsGlobalOpt::getFQDNFlagS()
+{
+    return FQDNFlagS;
+}
+
+void TClntParsGlobalOpt::setAuthEnabled(bool enabled)
+{
+    AuthEnabled = enabled;
+    Log(Debug) << "AUTH: Authentication " << (enabled?"enabled":"disabled") << "." << LogEnd;
+}
+
+bool TClntParsGlobalOpt::getAuthEnabled()
+{
+    return AuthEnabled;
+}
+
+void TClntParsGlobalOpt::setMappingPrefix(bool useMP)
+{
+    ExperimentalMappingPrefix = useMP;
+    Log(Notice) << "Experimental: mappix-prefix " << (useMP?"enabled":"disabled") << LogEnd;
+}
+
+bool TClntParsGlobalOpt::getMappingPrefix()
+{
+    return ExperimentalMappingPrefix;
+}
