@@ -44,6 +44,7 @@ List(TClntCfgIA)    ClntCfgIALst;		                            \
 List(TClntCfgTA)    ClntCfgTALst;                                           \
 List(TClntCfgPD)    ClntCfgPDLst;                                           \
 List(TClntCfgAddr)  ClntCfgAddrLst;                                         \
+List(DigestTypes)   DigestLst;                                              \
 /*Pointer to list which should contain either rejected servers or */        \
 /*preffered servers*/                                                       \
 TContainer<SmartPtr<TStationID> > PresentStationLst;                        \
@@ -79,7 +80,7 @@ SPtr<TDUID> DUIDEnterpriseID;
     DUIDType = DUID_TYPE_NOT_DEFINED;                                       \
     DUIDEnterpriseID = 0;
 
-#line 78 "ClntParser.y"
+#line 79 "ClntParser.y"
 typedef union    
 {
     int ival;    
@@ -275,43 +276,52 @@ typedef
 #define	NIS_DOMAIN_	271
 #define	NISP_DOMAIN_	272
 #define	FQDN_	273
-#define	LIFETIME_	274
-#define	VENDOR_SPEC_	275
-#define	IFACE_	276
-#define	NO_CONFIG_	277
-#define	REJECT_SERVERS_	278
-#define	PREFERRED_SERVERS_	279
-#define	IA_	280
-#define	TA_	281
-#define	IAID_	282
-#define	ADDRES_	283
-#define	IPV6ADDR_	284
-#define	WORKDIR_	285
-#define	RAPID_COMMIT_	286
-#define	OPTION_	287
-#define	SCRIPTS_DIR_	288
-#define	LOGNAME_	289
-#define	LOGLEVEL_	290
-#define	LOGMODE_	291
-#define	STRING_	292
-#define	HEXNUMBER_	293
-#define	INTNUMBER_	294
-#define	DUID_	295
-#define	STRICT_RFC_NO_ROUTING_	296
-#define	PD_	297
-#define	DUID_TYPE_	298
-#define	DUID_TYPE_LLT_	299
-#define	DUID_TYPE_LL_	300
-#define	DUID_TYPE_EN_	301
-#define	AUTH_	302
-#define	DIGEST_NONE_	303
-#define	DIGEST_HMAC_SHA1_	304
-#define	STATELESS_	305
-#define	ANON_INF_REQUEST_	306
-#define	INSIST_MODE_	307
-#define	INACTIVE_MODE_	308
-#define	EXPERIMENTAL_	309
-#define	ADDR_PARAMS_	310
+#define	FQDN_S_	274
+#define	LIFETIME_	275
+#define	VENDOR_SPEC_	276
+#define	IFACE_	277
+#define	NO_CONFIG_	278
+#define	REJECT_SERVERS_	279
+#define	PREFERRED_SERVERS_	280
+#define	IA_	281
+#define	TA_	282
+#define	IAID_	283
+#define	ADDRES_	284
+#define	IPV6ADDR_	285
+#define	WORKDIR_	286
+#define	RAPID_COMMIT_	287
+#define	OPTION_	288
+#define	SCRIPTS_DIR_	289
+#define	LOGNAME_	290
+#define	LOGLEVEL_	291
+#define	LOGMODE_	292
+#define	STRING_	293
+#define	HEXNUMBER_	294
+#define	INTNUMBER_	295
+#define	DUID_	296
+#define	STRICT_RFC_NO_ROUTING_	297
+#define	PD_	298
+#define	DUID_TYPE_	299
+#define	DUID_TYPE_LLT_	300
+#define	DUID_TYPE_LL_	301
+#define	DUID_TYPE_EN_	302
+#define	AUTH_ENABLED_	303
+#define	AUTH_ACCEPT_METHODS_	304
+#define	DIGEST_NONE_	305
+#define	DIGEST_PLAIN_	306
+#define	DIGEST_HMAC_MD5_	307
+#define	DIGEST_HMAC_SHA1_	308
+#define	DIGEST_HMAC_SHA224_	309
+#define	DIGEST_HMAC_SHA256_	310
+#define	DIGEST_HMAC_SHA384_	311
+#define	DIGEST_HMAC_SHA512_	312
+#define	STATELESS_	313
+#define	ANON_INF_REQUEST_	314
+#define	INSIST_MODE_	315
+#define	INACTIVE_MODE_	316
+#define	EXPERIMENTAL_	317
+#define	ADDR_PARAMS_	318
+#define	MAPPING_PREFIX_	319
 
 
 #line 169 "../bison++/bison.h"
@@ -376,6 +386,7 @@ static const int NISP_SERVER_;
 static const int NIS_DOMAIN_;
 static const int NISP_DOMAIN_;
 static const int FQDN_;
+static const int FQDN_S_;
 static const int LIFETIME_;
 static const int VENDOR_SPEC_;
 static const int IFACE_;
@@ -404,15 +415,23 @@ static const int DUID_TYPE_;
 static const int DUID_TYPE_LLT_;
 static const int DUID_TYPE_LL_;
 static const int DUID_TYPE_EN_;
-static const int AUTH_;
+static const int AUTH_ENABLED_;
+static const int AUTH_ACCEPT_METHODS_;
 static const int DIGEST_NONE_;
+static const int DIGEST_PLAIN_;
+static const int DIGEST_HMAC_MD5_;
 static const int DIGEST_HMAC_SHA1_;
+static const int DIGEST_HMAC_SHA224_;
+static const int DIGEST_HMAC_SHA256_;
+static const int DIGEST_HMAC_SHA384_;
+static const int DIGEST_HMAC_SHA512_;
 static const int STATELESS_;
 static const int ANON_INF_REQUEST_;
 static const int INSIST_MODE_;
 static const int INACTIVE_MODE_;
 static const int EXPERIMENTAL_;
 static const int ADDR_PARAMS_;
+static const int MAPPING_PREFIX_;
 
 
 #line 212 "../bison++/bison.h"
@@ -437,43 +456,52 @@ static const int ADDR_PARAMS_;
 	,NIS_DOMAIN_=271
 	,NISP_DOMAIN_=272
 	,FQDN_=273
-	,LIFETIME_=274
-	,VENDOR_SPEC_=275
-	,IFACE_=276
-	,NO_CONFIG_=277
-	,REJECT_SERVERS_=278
-	,PREFERRED_SERVERS_=279
-	,IA_=280
-	,TA_=281
-	,IAID_=282
-	,ADDRES_=283
-	,IPV6ADDR_=284
-	,WORKDIR_=285
-	,RAPID_COMMIT_=286
-	,OPTION_=287
-	,SCRIPTS_DIR_=288
-	,LOGNAME_=289
-	,LOGLEVEL_=290
-	,LOGMODE_=291
-	,STRING_=292
-	,HEXNUMBER_=293
-	,INTNUMBER_=294
-	,DUID_=295
-	,STRICT_RFC_NO_ROUTING_=296
-	,PD_=297
-	,DUID_TYPE_=298
-	,DUID_TYPE_LLT_=299
-	,DUID_TYPE_LL_=300
-	,DUID_TYPE_EN_=301
-	,AUTH_=302
-	,DIGEST_NONE_=303
-	,DIGEST_HMAC_SHA1_=304
-	,STATELESS_=305
-	,ANON_INF_REQUEST_=306
-	,INSIST_MODE_=307
-	,INACTIVE_MODE_=308
-	,EXPERIMENTAL_=309
-	,ADDR_PARAMS_=310
+	,FQDN_S_=274
+	,LIFETIME_=275
+	,VENDOR_SPEC_=276
+	,IFACE_=277
+	,NO_CONFIG_=278
+	,REJECT_SERVERS_=279
+	,PREFERRED_SERVERS_=280
+	,IA_=281
+	,TA_=282
+	,IAID_=283
+	,ADDRES_=284
+	,IPV6ADDR_=285
+	,WORKDIR_=286
+	,RAPID_COMMIT_=287
+	,OPTION_=288
+	,SCRIPTS_DIR_=289
+	,LOGNAME_=290
+	,LOGLEVEL_=291
+	,LOGMODE_=292
+	,STRING_=293
+	,HEXNUMBER_=294
+	,INTNUMBER_=295
+	,DUID_=296
+	,STRICT_RFC_NO_ROUTING_=297
+	,PD_=298
+	,DUID_TYPE_=299
+	,DUID_TYPE_LLT_=300
+	,DUID_TYPE_LL_=301
+	,DUID_TYPE_EN_=302
+	,AUTH_ENABLED_=303
+	,AUTH_ACCEPT_METHODS_=304
+	,DIGEST_NONE_=305
+	,DIGEST_PLAIN_=306
+	,DIGEST_HMAC_MD5_=307
+	,DIGEST_HMAC_SHA1_=308
+	,DIGEST_HMAC_SHA224_=309
+	,DIGEST_HMAC_SHA256_=310
+	,DIGEST_HMAC_SHA384_=311
+	,DIGEST_HMAC_SHA512_=312
+	,STATELESS_=313
+	,ANON_INF_REQUEST_=314
+	,INSIST_MODE_=315
+	,INACTIVE_MODE_=316
+	,EXPERIMENTAL_=317
+	,ADDR_PARAMS_=318
+	,MAPPING_PREFIX_=319
 
 
 #line 215 "../bison++/bison.h"
