@@ -7,7 +7,7 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: ClntIfaceMgr.cpp,v 1.40 2007-05-05 12:31:59 thomson Exp $
+ * $Id: ClntIfaceMgr.cpp,v 1.44 2008-06-18 20:18:03 thomson Exp $
  */
 
 #include "Portable.h"
@@ -17,7 +17,10 @@
 #include "ClntMsgReply.h"
 #include "ClntMsgAdvertise.h"
 #include "Logger.h"
+
+#ifndef MOD_CLNT_DISABLE_DNSUPDATE
 #include "DNSUpdate.h"
+#endif
 
 using namespace logger;
 using namespace std;
@@ -100,8 +103,12 @@ SmartPtr<TClntMsg> TClntIfaceMgr::select(unsigned int timeout)
         case ADVERTISE_MSG:
             ptr = new TClntMsgAdvertise(That, ClntTransMgr, ClntCfgMgr, ClntAddrMgr,
                 ifaceid,peer,buf,bufsize);
-            if (!ptr->validateAuthInfo(buf, bufsize))
+#ifndef MOD_DISABLE_AUTH
+            if (!ptr->validateAuthInfo(buf, bufsize, ClntCfgMgr->getAuthAcceptMethods())) {
+                    Log(Error) << "Message dropped, authentication validation failed." << LogEnd;
                     return 0;
+            }
+#endif
             return ptr;
         case SOLICIT_MSG:
         case REQUEST_MSG:
@@ -116,8 +123,12 @@ SmartPtr<TClntMsg> TClntIfaceMgr::select(unsigned int timeout)
         case REPLY_MSG:
             ptr = new TClntMsgReply(That, ClntTransMgr, ClntCfgMgr, ClntAddrMgr,
                 ifaceid, peer, buf, bufsize);
-            if (!ptr->validateAuthInfo(buf, bufsize))
+#ifndef MOD_DISABLE_AUTH
+            if (!ptr->validateAuthInfo(buf, bufsize, ClntCfgMgr->getAuthAcceptMethods())) {
+                    Log(Error) << "Message dropped, authentication validation failed." << LogEnd;
                     return 0;
+            }
+#endif
             return ptr;
 
         case RECONFIGURE_MSG:
@@ -126,7 +137,7 @@ SmartPtr<TClntMsg> TClntIfaceMgr::select(unsigned int timeout)
         case RELAY_FORW_MSG: // those two msgs should not be visible for client
         case RELAY_REPL_MSG:
         default:
-            Log(Warning) << "Message type " << msgtype << " must not be recevied by client. Check your relay/server configuration." << LogEnd;
+            Log(Warning) << "Message type " << msgtype << " is not supposed to be received by client. Check your relay/server configuration." << LogEnd;
             return 0;
         }
     } else {
@@ -387,8 +398,41 @@ bool TClntIfaceMgr::modifyPrefix(int iface, SPtr<TIPv6Addr> prefix, int prefixLe
         return false;
     }
 
+
+    if (ClntCfgMgr->getMappingPrefix()) {
+	char buf[128];
+	char cmd1[]="./mappingprefixadd";
+	char cmd2[]="./mappingprefixdel";
+	int returnCode = 0;
+	switch (mode) {
+	case PREFIX_MODIFY_ADD:
+	{
+	    sprintf(buf, "%s %s", cmd1, prefix->getPlain());
+	    Log(Notice) << "Executing external command to ADD prefix: " << buf << LogEnd;
+	    returnCode = system(buf);
+	    Log(Notice) << "ReturnCode = " << returnCode << LogEnd;
+	    break;
+	}
+	case PREFIX_MODIFY_DEL:
+	{
+	    sprintf(buf, "%s %s", cmd2, prefix->getPlain());
+	    Log(Notice) << "Executing external command to DEL prefix: " << buf << LogEnd;
+	    returnCode = system(buf);
+	    Log(Notice) << "ReturnCode = " << returnCode << LogEnd;
+	    break;
+	}
+	default:
+	{
+
+	}
+	}
+	
+	return true; // added successfully
+    }
+
+
     string action;
-    int status;
+    int status = -1;
 
     switch (mode) {
     case PREFIX_MODIFY_ADD:
