@@ -7,7 +7,7 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: ClntMsg.cpp,v 1.30 2007-07-05 00:17:41 thomson Exp $
+ * $Id: ClntMsg.cpp,v 1.36 2008-06-02 00:15:00 thomson Exp $
  */
 
 #ifdef WIN32
@@ -48,7 +48,13 @@
 #include "ClntOptNISPServer.h"
 #include "ClntOptNISPDomain.h"
 #include "ClntOptLifetime.h"
+
+#ifndef MOD_DISABLE_AUTH
+#include "ClntOptAAAAuthentication.h"
+#include "ClntOptKeyGeneration.h"
 #include "ClntOptAuthentication.h"
+#endif
+
 #include "Logger.h"
 
 string msgs[] = { "",
@@ -64,11 +70,13 @@ string msgs[] = { "",
 		  "RECONFIGURE",
 		  "INF-REQUEST",
 		  "RELAY-FORWARD"
-		  "RELAY-REPLY"};
+		  "RELAY-REPLY",
+          "LEASEQUERY",
+          "LEASEQUERY-REPLY"};
 
 void TClntMsg::invalidAllowOptInMsg(int msg, int opt) {
     string name;
-    if (msg<=13)
+    if (msg<=15)
 	name = msgs[msg];
     Log(Warning) << "Option " << opt << " is not allowed in the " << name
 		 << " message. Ignoring." << LogEnd;
@@ -76,7 +84,7 @@ void TClntMsg::invalidAllowOptInMsg(int msg, int opt) {
 
 void TClntMsg::invalidAllowOptInOpt(int msg, int parentOpt, int childOpt) {
     string name;
-    if (msg<=13)
+    if (msg<=15)
 	name = msgs[msg];
 
     if (parentOpt==0)
@@ -213,16 +221,20 @@ TClntMsg::TClntMsg(SmartPtr<TClntIfaceMgr> IfaceMgr,
 	    ptr = (Ptr*) ta;
 	    break;
 	}
-	case OPTION_AUTH:
-	    // FIXME: set this->DigestType to real DigestType
-        if (ClntCfgMgr->getDigest()!=DIGEST_NONE)
-            this->DigestType = DIGEST_HMAC_SHA1;
-	    // FIXME: set this->DigestType to real DigestType
-        if (ClntCfgMgr->getDigest()!=DIGEST_NONE)
-            this->DigestType = DIGEST_HMAC_SHA1;
-	    ptr = new TClntOptAuthentication(buf+pos, length, this);
-	    Log(Notice) << "[s] parsed OPTION_AUTH in message" << LogEnd;
+#ifndef MOD_DISABLE_AUTH
+	case OPTION_AAAAUTH:
+	    Log(Warning) << "Option OPTION_AAAAUTH received by client is invalid, ignoring." << LogEnd;
 	    break;
+	case OPTION_KEYGEN:
+	    ptr = new TClntOptKeyGeneration(buf+pos, length, this);
+	    break;
+	case OPTION_AUTH:
+	    if (ClntCfgMgr->getAuthEnabled()) {
+                this->DigestType = ClntCfgMgr->getDigest();
+                ptr = new TClntOptAuthentication(buf+pos, length, this);
+	    }
+	    break;
+#endif
 	case OPTION_VENDOR_OPTS: {
 	    SmartPtr<TClntOptVendorSpec> vendor = new TClntOptVendorSpec(buf+pos, length, this);
 	    ptr = (Ptr*) vendor;
@@ -276,7 +288,10 @@ TClntMsg::TClntMsg(SmartPtr<TClntIfaceMgr> IfaceMgr,
                    :TMsg(iface,addr,msgType)
 {
     setAttribs(IfaceMgr,TransMgr,CfgMgr,AddrMgr);
+#ifndef MOD_DISABLE_AUTH
     this->DigestType = CfgMgr->getDigest();
+    this->AuthKeys = CfgMgr->AuthKeys;
+#endif
 }
 
 void TClntMsg::setAttribs(SmartPtr<TClntIfaceMgr> IfaceMgr, 
@@ -298,6 +313,12 @@ void TClntMsg::setAttribs(SmartPtr<TClntIfaceMgr> IfaceMgr,
     MRT = 0;
     MRC = 0;
     MRD = 0;
+
+#ifndef MOD_DISABLE_AUTH
+    this->AuthKeys = CfgMgr->AuthKeys;
+#endif
+    this->KeyGenNonce = NULL;
+    this->KeyGenNonceLen = 0;
 }
 
 unsigned long TClntMsg::getTimeout()
@@ -337,6 +358,12 @@ void TClntMsg::send()
     LastTimeStamp = now();
 }
 
+void TClntMsg::copyAAASPI(SmartPtr<TClntMsg> q) {
+    this->AAASPI = q->getAAASPI();
+    this->SPI = q->getSPI();
+    this->AuthInfoKey = q->getAuthInfoKey();
+}
+
 SmartPtr<TClntTransMgr> TClntMsg::getClntTransMgr()
 {
     return this->ClntTransMgr;
@@ -379,6 +406,41 @@ void TClntMsg::setIface(int iface) {
     }
 }
 
+/** 
+ * this function appends authentication option
+ * 
+ * @param duid 
+ * @param addr 
+ * @param iface 
+ * @param reqOpts 
+ * 
+ */
+void TClntMsg::appendAuthenticationOption(SmartPtr<TClntAddrMgr> AddrMgr)
+{
+#ifndef MOD_DISABLE_AUTH
+    if (!ClntCfgMgr->getAuthEnabled() || ClntCfgMgr->getDigest() == DIGEST_NONE) {
+        Log(Debug) << "Authentication is disabled, not including auth options in message." << LogEnd;
+        this->DigestType = DIGEST_NONE;
+        return;
+    }
+
+    this->DigestType = ClntCfgMgr->getDigest();
+
+    if (!getOption(OPTION_AUTH)) {
+        ClntAddrMgr->firstClient();
+        SmartPtr<TAddrClient> client = ClntAddrMgr->getClient();
+        if (client && client->getSPI())
+            this->setSPI(client->getSPI());
+        if (client)
+            this->ReplayDetection = client->getNextReplayDetectionSent();
+        else
+            this->ReplayDetection = 1;
+        Options.append(new TClntOptAuthentication(this));
+        if (client)
+            client->setSPI(this->getSPI());
+    }
+#endif
+}
 
 /*
  * this method adds requested (which have status==STATE_NOTCONFIGURED) options
@@ -394,6 +456,16 @@ void TClntMsg::appendRequestedOptions() {
     
     SmartPtr<TClntOptOptionRequest> optORO = new TClntOptOptionRequest(iface, this);
 
+    if (iface->getUnicast()) {
+	optORO->addOption(OPTION_UNICAST);
+	Log(Debug) << "Adding UNICAST to ORO." << LogEnd;
+    }
+
+    if (ClntCfgMgr->addInfRefreshTime()) {
+	optORO->addOption(OPTION_INFORMATION_REFRESH_TIME);
+	Log(Debug) << "#### Adding INFORMATION REFRESH TIME to ORO." << LogEnd;
+    }
+
     // --- option: DNS-SERVERS ---
     if ( iface->isReqDNSServer() && (iface->getDNSServerState()==STATE_NOTCONFIGURED) ) {
 	optORO->addOption(OPTION_DNS_SERVERS);
@@ -479,6 +551,7 @@ void TClntMsg::appendRequestedOptions() {
 	string fqdn = iface->getProposedFQDN();
 	{
 	    SmartPtr<TClntOptFQDN> opt = new TClntOptFQDN( fqdn,this );
+	    opt->setSFlag(ClntCfgMgr->getFQDNFlagS());
 	    Options.append( (Ptr*)opt );
 	}
 	iface->setFQDNState(STATE_INPROCESS);
@@ -566,12 +639,33 @@ void TClntMsg::appendRequestedOptions() {
     // include ELAPSED option
     Options.append(new TClntOptElapsed(this));
 
-    // --- option: AUTH ---
-    // FIXME: Implement authorisation for real
-    if (ClntCfgMgr->getDigest()!=DIGEST_NONE) {
-	Options.append(new TClntOptAuthentication(0, this));
+#ifndef MOD_DISABLE_AUTH
+    if (this->MsgType == SOLICIT_MSG) {
+            if (ClntCfgMgr->getAuthEnabled()) {
+                    // --- option: AAAAUTH ---
+                    Options.append(new TClntOptAAAAuthentication(this));
+
+                    // request KeyGeneration
+                    optORO->addOption(OPTION_KEYGEN);
+                    // request Authentication
+                    optORO->addOption(OPTION_AUTH);
+            }
     } else {
+        /*
+            // --- option: AUTH ---
+            if (ClntCfgMgr->getAuthEnabled() && ClntCfgMgr->getDigest()!=DIGEST_NONE) {
+                    Log(Debug) << "Authentication enabled, adding AUTH option." << LogEnd;
+                    ClntAddrMgr->firstClient();
+                    SmartPtr<TAddrClient> client = ClntAddrMgr->getClient();
+                    if (client && client->getSPI())
+                        this->setSPI(client->getSPI());
+                    Options.append(new TClntOptAuthentication(this));
+                    client->setSPI(this->getSPI());
+            }
+            */
     }
+#endif
+
     // final setup: Did we add any options at all? 
     if ( optORO->count() ) 
 	Options.append( (Ptr*) optORO );
@@ -703,6 +797,19 @@ void TClntMsg::answer(SPtr<TClntMsg> reply)
 		break;
 	    }
 
+	    SmartPtr<TOpt> requestOpt;
+	    this->Options.first();
+	    while (requestOpt = this->Options.get()) {
+		if (requestOpt->getOptType() != OPTION_IA_TA)
+		    continue;
+		SPtr<TClntOptTA> reqTA = (Ptr*) requestOpt;
+		if (ta->getIAID() == reqTA->getIAID())
+		{
+		    this->Options.del();
+		    break;
+		}
+	    }
+
 	    ta->setIface(Iface);
 	    ta->doDuties();
 	    break;
@@ -781,6 +888,8 @@ void TClntMsg::answer(SPtr<TClntMsg> reply)
 	if (requestOpt->getOptType() == OPTION_IA_PD) pdLeft = true;
     }
 
+//    taLeft = false;
+
     if (iaLeft || taLeft || pdLeft) {
         // send new Request to another server
         Log(Notice) << "There are still " << (iaLeft?"some IA(s)":"") 
@@ -810,3 +919,35 @@ void TClntMsg::answer(SPtr<TClntMsg> reply)
     return;
 }
 
+bool TClntMsg::validateReplayDetection() {
+    if (this->MsgType == SOLICIT_MSG)
+        return true;
+
+    ClntAddrMgr->firstClient();
+    SmartPtr<TAddrClient> client = ClntAddrMgr->getClient();
+
+    if (!client) {
+        Log(Debug) << "Something is wrong, VERY wrong. Info about this client (myself) is not found." << LogEnd;
+        return true;
+    }
+
+    if (!client->getReplayDetectionRcvd() && !this->ReplayDetection)
+        return true;
+
+    if (client->getReplayDetectionRcvd() < this->ReplayDetection) {
+        Log(Debug)
+            << "Replay detection field should be greater than "
+            << client->getReplayDetectionRcvd()
+            << " and it actually is "
+            << this->ReplayDetection << LogEnd;
+        client->setReplayDetectionRcvd(this->ReplayDetection);
+        return true;
+    } else {
+        Log(Warning) << "Replayed message detected: Replay detection field should be greater than "
+		     << client->getReplayDetectionRcvd()
+		     << ", but "
+		     << this->ReplayDetection
+		     << " received." << LogEnd;
+        return false;
+    }
+}
