@@ -3,12 +3,20 @@
  *
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>
  *          Marek Senderski <msend@o2.pl>
+ * changes: Michal Kowalczuk <michal@kowalczuk.eu>
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: ClntMsgAdvertise.cpp,v 1.5 2007-03-27 23:44:56 thomson Exp $
+ * $Id: ClntMsgAdvertise.cpp,v 1.7 2008-06-02 00:15:00 thomson Exp $
  *
  * $Log: ClntMsgAdvertise.cpp,v $
+ * Revision 1.7  2008-06-02 00:15:00  thomson
+ * AUTH is now a modular feature.
+ *
+ * Revision 1.6  2008-02-25 17:49:07  thomson
+ * Authentication added. Megapatch by Michal Kowalczuk.
+ * (small changes by Tomasz Mrugalski)
+ *
  * Revision 1.5  2007-03-27 23:44:56  thomson
  * Client now chooses server properly (bug #151)
  *
@@ -28,6 +36,10 @@
 #include "OptPreference.h"
 #include "ClntOptClientIdentifier.h"
 #include "ClntOptServerIdentifier.h"
+
+#ifndef MOD_DISABLE_AUTH
+#include "ClntOptKeyGeneration.h"
+#endif
 #include "ClntOptPreference.h"
 
 TClntMsgAdvertise::TClntMsgAdvertise(SmartPtr<TClntIfaceMgr> IfaceMgr,
@@ -80,8 +92,8 @@ string TClntMsgAdvertise::getInfo()
     SPtr<TClntOptPreference> pref;
     SPtr<TClntOptServerIdentifier> srvID;
 
-    pref  = (Ptr*) getOption(OPTION_PREFERENCE);
-    srvID = (Ptr*) getOption(OPTION_SERVERID);
+    pref   = (Ptr*) getOption(OPTION_PREFERENCE);
+    srvID  = (Ptr*) getOption(OPTION_SERVERID);
 
     if (srvID) {
 	tmp << "Server ID=" << srvID->getDUID()->getPlain();
@@ -94,6 +106,17 @@ string TClntMsgAdvertise::getInfo()
     } else {
 	tmp << ", no preference option, assumed 0";
     }
+
+#ifndef MOD_DISABLE_AUTH
+    SPtr<TClntOptKeyGeneration> keyGen;
+    keyGen = (Ptr*) getOption(OPTION_KEYGEN);
+    if (keyGen) {
+	tmp << ", keygen (AlgorithmId=" << keyGen->getAlgorithmId() << ")";
+	DigestType = (DigestTypes)keyGen->getAlgorithmId();
+    } else {
+	tmp << ", no auth info";
+    }
+#endif
     
     return tmp.str();
 }
