@@ -3,12 +3,17 @@
  *
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>
  *          Marek Senderski <msend@o2.pl>
+ * changes: Michal Kowalczuk <michal@kowalczuk.eu>
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: ClntMsgDecline.cpp,v 1.3 2005-01-08 16:52:03 thomson Exp $
+ * $Id: ClntMsgDecline.cpp,v 1.4 2008-02-25 17:49:07 thomson Exp $
  *
  * $Log: ClntMsgDecline.cpp,v $
+ * Revision 1.4  2008-02-25 17:49:07  thomson
+ * Authentication added. Megapatch by Michal Kowalczuk.
+ * (small changes by Tomasz Mrugalski)
+ *
  * Revision 1.3  2005-01-08 16:52:03  thomson
  * Relay support implemented.
  *
@@ -55,6 +60,9 @@ TClntMsgDecline::TClntMsgDecline(SmartPtr<TClntIfaceMgr> IfaceMgr,
     while ( ptrIA = IALst.get() ) {
 	Options.append( new TClntOptIA_NA(ptrIA,this));
     }
+
+    appendAuthenticationOption(AddrMgr);
+
     pkt = new char[getSize()];
 
 }
