@@ -3,10 +3,12 @@
  *
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>
  *          Marek Senderski <msend@o2.pl>
- * chanmges: Krzysztof Wnuk <keczi@poczta.onet.pl>
+ * changes: Krzysztof Wnuk <keczi@poczta.onet.pl>
+ *          Michal Kowalczuk <michal@kowalczuk.eu>
+ *
  * released under GNU GPL v2 or later licence
  *
- * $Id: ClntMsgRelease.cpp,v 1.15 2007-04-22 21:19:28 thomson Exp $
+ * $Id: ClntMsgRelease.cpp,v 1.17 2008-06-18 20:18:41 thomson Exp $
  */
 
 #include "ClntMsgRelease.h"
@@ -26,7 +28,10 @@
 #include "AddrMgr.h"
 #include "AddrIA.h"
 #include "AddrAddr.h"
+
+#ifndef MOD_CLNT_DISABLE_DNSUPDATE
 #include "DNSUpdate.h"
+#endif
 
 /** 
  * create RELEASE message
@@ -124,6 +129,8 @@ TClntMsgRelease::TClntMsgRelease(
 	AddrMgr->delPD(pd->getIAID() );
     }
 
+    appendAuthenticationOption(AddrMgr);
+
     pkt = new char[getSize()];
     IsDone = false;
 }
