@@ -4,9 +4,11 @@
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>
  *          Marek Senderski <msend@o2.pl>
  * changes: Krzysztof Wnuk <keczi@poczta.onet.pl>
+ *          Michal Kowalczuk <michal@kowalczuk.eu>
+ *
  * released under GNU GPL v2 or later licence
  *
- * $Id: ClntMsgRenew.cpp,v 1.15 2007-05-04 17:22:49 thomson Exp $
+ * $Id: ClntMsgRenew.cpp,v 1.17 2008-03-06 21:36:57 thomson Exp $
  *
  */
 
@@ -56,6 +58,12 @@ TClntMsgRenew::TClntMsgRenew(SmartPtr<TClntIfaceMgr> IfaceMgr,
 	ia = PDLst.get();
     }
 
+    if (!ia) {
+	Log(Error) << "No IA to renew. Something is wrong." << LogEnd;
+	IsDone = true;
+	return;
+    }
+
     MRD      = ia->getT2Timeout();  
     Iface    = ia->getIface();
     PeerAddr = ia->getSrvAddr();
@@ -87,6 +95,8 @@ TClntMsgRenew::TClntMsgRenew(SmartPtr<TClntIfaceMgr> IfaceMgr,
 	Options.append(new TClntOptIA_PD(ia, this));
     }
 
+    appendAuthenticationOption(AddrMgr);
+
     pkt = new char[getSize()];
     this->IsDone = false;
     this->send();
