@@ -3,21 +3,10 @@
  *
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>
  *          Marek Senderski <msend@o2.pl>
- *
+ * changes: Krzysztof Wnuk <keczi@poczta.onet.pl>
  * released under GNU GPL v2 or later licence
  *
- * $Id: ClntMsgSolicit.h,v 1.4 2005/01/08 16:52:03 thomson Exp $
- *
- * $Log: ClntMsgSolicit.h,v $
- * Revision 1.4  2005/01/08 16:52:03  thomson
- * Relay support implemented.
- *
- * Revision 1.3  2004/09/07 22:02:33  thomson
- * pref/valid/IAID is not unsigned, RAPID-COMMIT now works ok.
- *
- * Revision 1.2  2004/06/20 17:51:48  thomson
- * getName() method implemented, comment cleanup
- *
+ * $Id: ClntMsgSolicit.h,v 1.6 2007-01-27 17:12:24 thomson Exp $
  *
  */
 
@@ -38,10 +27,12 @@ public:
 		    SmartPtr<TClntAddrMgr>  AddrMgr,
 		    int iface,
 		    SmartPtr<TIPv6Addr> addr,
-		    TContainer< SmartPtr<TClntCfgIA> > IAs, bool rapid=false);
-    
+		    List(TClntCfgIA) iaLst, 
+		    SPtr<TClntCfgTA> ta,
+		    List(TClntCfgPD) pdLst,
+		    bool rapid=false);
+
     void answer(SmartPtr<TClntMsg> msg);
-    void replyReceived(SmartPtr<TClntMsg> msg);
 
     void doDuties();
     bool shallRejectAnswer(SmartPtr<TClntMsg> msg);
@@ -51,8 +42,6 @@ public:
     ~TClntMsgSolicit();
 
  private:
-    List(TMsg) AnswersLst;
-
     // method returns max. preference value of received ADVERTISE messages
     int getMaxPreference();
 };
