@@ -5,33 +5,31 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: ClntOptAuthentication.cpp,v 1.2 2006-11-24 01:33:43 thomson Exp $
- *
- * $Log: ClntOptAuthentication.cpp,v $
- * Revision 1.2  2006-11-24 01:33:43  thomson
- * *** empty log message ***
- *
- * Revision 1.1  2006-11-17 00:38:54  thomson
- * Partial AUTH support by Sammael, fixes by thomson
- *
+ * $Id: ClntOptAuthentication.cpp,v 1.3 2008-02-25 17:49:08 thomson Exp $
  *
  */
+
 #include "ClntOptAuthentication.h"
+#include "ClntMsg.h"
 
 TClntOptAuthentication::TClntOptAuthentication( char * buf,  int n, TMsg* parent)
 	:TOptAuthentication(buf, n, parent)
 {
 }
 
-TClntOptAuthentication::TClntOptAuthentication(uint64_t ReplayDet, TMsg* parent)
+TClntOptAuthentication::TClntOptAuthentication(TMsg* parent)
     :TOptAuthentication(parent)
 {
     setRDM(0);
-    setReplayDet(ReplayDet);
-    setSPI(69);
 }
 
 bool TClntOptAuthentication::doDuties()
 {
+    int ifindex = this->Parent->getIface();
+    TClntMsg * msg = (TClntMsg*)(this->Parent);
+    SmartPtr<TClntCfgMgr> cfgMgr = msg->getClntCfgMgr();
+    SmartPtr<TClntCfgIface> cfgIface = cfgMgr->getIface(ifindex);
+    cfgIface->setAuthenticationState(STATE_CONFIGURED);
+
     return false;
 }
