@@ -6,9 +6,15 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: ClntOptClientIdentifier.cpp,v 1.5 2006/01/29 10:48:31 thomson Exp $
+ * $Id: ClntOptClientIdentifier.cpp,v 1.6 2006-03-05 21:38:20 thomson Exp $
  *
  * $Log: ClntOptClientIdentifier.cpp,v $
+ * Revision 1.6  2006-03-05 21:38:20  thomson
+ * TA support merged.
+ *
+ * Revision 1.5.2.1  2006/02/05 23:38:07  thomson
+ * Devel branch with Temporary addresses support added.
+ *
  * Revision 1.5  2006/01/29 10:48:31  thomson
  * Base class changed.
  *
@@ -28,12 +34,12 @@
 
 
 TClntOptClientIdentifier::TClntOptClientIdentifier(char * duid, int n, TMsg* parent)
-    :TOptDUID(duid,n, parent)
+    :TOptDUID(OPTION_CLIENTID, duid,n, parent)
 {
 }
 
 TClntOptClientIdentifier::TClntOptClientIdentifier(SmartPtr<TDUID> duid, TMsg* parent)
-    :TOptDUID(duid, parent)
+    :TOptDUID(OPTION_CLIENTID, duid, parent)
 {
 }
 
