@@ -10,13 +10,17 @@
 #ifndef CLNTOPTELAPSED_H
 #define CLNTOPTELAPSED_H
 
-#include "OptInteger4.h"
+#include "OptInteger.h"
 
-class TClntOptElapsed : public TOptInteger4
+class TClntOptElapsed : public TOptInteger
 {
   public:
     TClntOptElapsed(TMsg* parent);
     TClntOptElapsed( char * buf,  int n, TMsg* parent);
+
+    char * storeSelf(char* buf);
     bool doDuties();
+private:
+    unsigned long Timestamp;
 };
 #endif
