@@ -6,9 +6,15 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: ClntOptServerIdentifier.cpp,v 1.5 2006/01/29 10:48:31 thomson Exp $
+ * $Id: ClntOptServerIdentifier.cpp,v 1.6 2006-03-05 21:38:20 thomson Exp $
  *
  * $Log: ClntOptServerIdentifier.cpp,v $
+ * Revision 1.6  2006-03-05 21:38:20  thomson
+ * TA support merged.
+ *
+ * Revision 1.5.2.1  2006/02/05 23:38:07  thomson
+ * Devel branch with Temporary addresses support added.
+ *
  * Revision 1.5  2006/01/29 10:48:31  thomson
  * Base class changed.
  *
@@ -27,12 +33,12 @@
 #include "ClntOptServerIdentifier.h"
 
 TClntOptServerIdentifier::TClntOptServerIdentifier( char * duid,  int n, TMsg* parent)
-	:TOptDUID(duid,n, parent) {
+	:TOptDUID(OPTION_SERVERID, duid,n, parent) {
 
 }
 
 TClntOptServerIdentifier::TClntOptServerIdentifier(SmartPtr<TDUID> duid, TMsg* parent)
-    :TOptDUID(duid, parent) {
+    :TOptDUID(OPTION_SERVERID, duid, parent) {
 
 }
 
