@@ -5,12 +5,14 @@
  *          Marek Senderski <msend@o2.pl>                                    
  * changes: Michal Kowalczuk <michal@kowalczuk.eu>
  *                                                                           
- * $Id: DHCPConst.cpp,v 1.13 2007-04-22 21:19:29 thomson Exp $
+ * $Id: DHCPConst.cpp,v 1.17 2008-06-18 21:55:59 thomson Exp $
  *
  * released under GNU GPL v2 or later licence                                
  *                                                                           
  */
 #include "DHCPConst.h"
+#include "Logger.h"
+#include "SmartPtr.h"
 
 
 // standard options specified in RFC3315, pg. 99
@@ -19,7 +21,7 @@ bool OptInMsg[13][20] = {
 //             ID     ID                       Request       Time  Msg.   Empty       Unica.   Code  Comm. Class Class  Spec.    ID    Msg.  Accept
 /*Solicit */ {true,  false, true,  true, false, true, false, true, false, false,true, false, false,  true, true, true,  true, false, false,true },
 /*Advertise*/{true,  true , true,  true, false, false,true , false,false, false,true, true,  true ,  false,true, true,  true, false, false,true },
-/*Request*/  {true,  true , true,  true, false, true, false, true, false, false,true, false, false,  false,true, true,  true, false, false,true },                
+/*Request*/  {true,  true , true,  true, false, true, false, true, false, false,true, false, false,  false,true, true,  true, false, false,true },
 /*Confirm*/  {true,  false, true,  true, false, true, false, true, false, false,true, false, false,  false,true, true,  true, false, false,false},
 /*Renew*/    {true,  true , true,  true, false, true, false, true, false, false,true, false, false,  false,true, true,  true, false, false, true},
 /*Rebind*/   {true,  false, true,  true, false, true, false, true, false, false,true, false, false,  false,true, true,  true, false, false, true},
@@ -35,6 +37,8 @@ bool OptInMsg[13][20] = {
 int allowOptInMsg(int msg, int opt)
 {
     // standard options specified in RFC3315
+    if (msg>13)
+	return 1; // allow everthing in new messages
     if (opt <=20) {
 	    return OptInMsg[msg-1][opt-1];
     }
@@ -101,22 +105,62 @@ int allowOptInOpt(int msgType, int parent, int subopt) {
     case OPTION_IA_PD:
 	if ( (subopt==OPTION_IAPREFIX) || (subopt==OPTION_STATUS_CODE))
 	    return 1;
+    case OPTION_LQ_QUERY:
+      if ( (subopt == OPTION_IAADDR) || (subopt==OPTION_CLIENTID) )
+	return 1;
     }
     return 0;
 }
 
-/* see Misc/DHCPConst.h */
 unsigned DIGESTSIZE[] = {
         0,  //NONE
         32, //PLAIN
-        16, //MD5
+        16, //HMAC-MD5
         20, //HMAC-SHA1
         28, //HMAC-SHA224
         32, //HMAC-SHA256
         48, //HMAC-SHA384
-        64  //HMAC-SHA512
+        64, //HMAC-SHA512
+        0   //_END_
+};
+
+char *DIGESTNAME[] = {
+    (char *)"NONE",
+    (char *)"PLAIN",
+    (char *)"HMAC-MD5",
+    (char *)"HMAC-SHA-1",
+    (char *)"HMAC-SHA-224",
+    (char *)"HMAC-SHA-256",
+    (char *)"HMAC-SHA-384",
+    (char *)"HMAC-SHA-512",
+    (char *)""   //_END_
 };
 
 unsigned getDigestSize(enum DigestTypes type) {
+        if (type >= DIGEST_INVALID) {
+                Log(Error) << "Invalid digest type: " << type << LogEnd;
+                return 0;
+        }
         return DIGESTSIZE[type];
 }
+
+char *getDigestName(enum DigestTypes type) {
+    return DIGESTNAME[type];
+}
+
+void PrintHex(std::string message, char *buffer, unsigned len) {
+    unsigned j;
+    char *buf = new char[len*3+1];
+
+    if (len) {
+        for (j = 0; j < len; j++) {
+            sprintf(buf + j*3, "%02x ", (unsigned char) *(buffer+j));
+        }
+
+        Log(Debug) << message << buf << LogEnd;
+    } else 
+        Log(Debug) << message << "N/A (zero length)" << LogEnd;
+
+    delete buf;
+}
+
