@@ -34,9 +34,9 @@
 #define INFORMATION_REQUEST_MSG 11
 #define RELAY_FORW_MSG 12
 #define RELAY_REPL_MSG 13
-// unimplemented messages
-#define LEASEQUERY     14
-#define LEASEQUERY_REPLY 15
+#define LEASEQUERY_MSG       14
+#define LEASEQUERY_REPLY_MSG 15
+
 // implementation specific
 #define CONTROL_MSG    255
 
@@ -148,25 +148,29 @@
 // RFC-ietf-dhc-dhcpv6-ero-01.txt
 #define OPTION_ERO              43
 
-// RFC-ietf-dhc-dhcpv6-leasequery-01.txt
+// RFC5007: Leasequery
 #define OPTION_LQ_QUERY         44
-
-// RFC-ietf-dhc-dhcpv6-leasequery-01.txt
 #define OPTION_CLIENT_DATA      45
-
-// RFC-ietf-dhc-dhcpv6-leasequery-01.txt
 #define OPTION_CLT_TIME         46
 #define OPTION_LQ_RELAY_DATA    47
 #define OPTION_LQ_CLIENT_LINK   48
 
+// The following option numbers are not yet standardized and
+// won't interoperate with other implementations
+// option formats taken from:
+// draft-ram-dhc-dhcpv6-aakey-01.txt
+#define OPTION_AAAAUTH              240
+#define OPTION_KEYGEN               241
+
 // Experimental implementation for address prefix length information
 // See: http://klub.com.pl/dhcpv6/doc/draft-mrugalski-addropts-XX-2007-04-17.txt
 #define OPTION_ADDRPARAMS           251
 
-// RFC-ietf-dhc-dhcpv6-leasequery-01.txt
-// -- Query types --
-#define QUERY_BY_ADDRESS  1
-#define QUERY_BY_CLIENTID 2
+// -- Query types (RFC5007) --
+typedef enum {
+    QUERY_BY_ADDRESS = 1,
+    QUERY_BY_CLIENTID = 2
+} ELeaseQueryType;
 
 // --- Option lengths --
 // (value of the len field, so actual option length is +4 bytes)
@@ -181,19 +185,19 @@
 #define STATUSCODE_NOTONLINK     4
 #define STATUSCODE_USEMULTICAST  5
 #define STATUSCODE_NOPREFIXAVAIL 6 
-// unimplemented codes
+// Leasequery status codes
 #define STATUSCODE_UNKNOWNQUERYTYPE 7
 #define STATUSCODE_MALFORMEDQUERY 8
 #define STATUSCODE_NOTCONFIGURED 9
 #define STATUSCODE_NOTALLOWED    10
 
-// INFINITY + 1 is 0. Hih, cool
+// INFINITY + 1 is 0. Hihi, cool
 #define DHCPV6_INFINITY (unsigned) 0xffffffff
 
-// how long should we wait before we assume that OS detected duplicated addresses (in secs)
+// How long should we wait before we assume that OS detected duplicated addresses (in secs)
 #define DADTIMEOUT (unsigned) 3
 
-// addresses reported ad DECLINED are not used for 2 hours
+// addresses reported as DECLINED are not used for 2 hours
 #define DECLINED_TIMEOUT (unsigned) 7200
 
 // DHCPv6 server default values
@@ -256,10 +260,30 @@ int allowOptInOpt(int msgType, int optOut, int optIn);
 int allowOptInMsg(int msgType, int optType);
 
 #ifdef WIN32
+//#define uint8_t  unsigned char
+//#define uint16_t unsigned short int
+//#define uint32_t unsigned int
+
+#ifndef uint8_t
+#define uint8_t  unsigned char
+#endif
+
+#ifndef uint16_t
 #define uint16_t unsigned short int
+#endif
+
+#ifndef uint32_t
 #define uint32_t unsigned int
 #endif
 
+#ifndef uint64_t
+#define uint64_t unsigned long long int
+#endif
+
+#else
+#include <stdint.h>
+#endif
+
 enum DigestTypes {
         DIGEST_NONE = 0,
         DIGEST_PLAIN = 1,
@@ -268,13 +292,17 @@ enum DigestTypes {
         DIGEST_HMAC_SHA224 = 4,
         DIGEST_HMAC_SHA256 = 5,
         DIGEST_HMAC_SHA384 = 6,
-        DIGEST_HMAC_SHA512 = 7
+        DIGEST_HMAC_SHA512 = 7,
+        //this must be last, increase it if necessary
+        DIGEST_INVALID = 8
 };
 
 unsigned getDigestSize(enum DigestTypes type);
+char *getDigestName(enum DigestTypes type);
         
-// for debugging purposes:
-#define printhex(buf, len) { unsigned j; for (j = 0; j < len; j++) printf("%02x ", (unsigned char) *(buf+j)); printf("\n"); }
+// key is generated this way:
+// key = HMAC-SHA1 (AAA-key, {Key Generation Nonce || client identifier})
+// so it's size is always size of HMAC-SHA1 result which is 160bits = 20bytes
+#define AUTHKEYLEN 20
 
 #endif
-
