@@ -6,10 +6,14 @@
  *
  * released under GNU GPL v2 licence
  *
- * $Id: OptGeneric.cpp,v 1.2 2005/01/24 00:42:57 thomson Exp $
+ * $Id: OptGeneric.cpp,v 1.3 2007-08-26 10:26:19 thomson Exp $
  *
  * $Log: OptGeneric.cpp,v $
- * Revision 1.2  2005/01/24 00:42:57  thomson
+ * Revision 1.3  2007-08-26 10:26:19  thomson
+ * Possible segfault in REBIND processing,
+ * gcc 4.3.0 conformance
+ *
+ * Revision 1.2  2005-01-24 00:42:57  thomson
  * no message
  *
  * Revision 1.1  2005/01/12 00:01:06  thomson
@@ -18,13 +22,8 @@
  */
 
 #include <stdlib.h>
-#ifdef LINUX
-#include <netinet/in.h>
-#endif 
-#ifdef WIN32
-#include <winsock2.h>
-#endif
-
+#include <string.h>
+#include "Portable.h"
 #include "DHCPConst.h"
 #include "OptGeneric.h"
 
