@@ -6,9 +6,19 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: OptOptionRequest.h,v 1.3 2006/02/02 23:17:17 thomson Exp $
+ * $Id: OptOptionRequest.h,v 1.5 2007-07-05 00:17:42 thomson Exp $
  *
  * $Log: OptOptionRequest.h,v $
+ * Revision 1.5  2007-07-05 00:17:42  thomson
+ * Security update: don't create world writable files,
+ * handle malformed option length.
+ *
+ * Revision 1.4  2006-03-05 21:37:46  thomson
+ * TA support merged.
+ *
+ * Revision 1.3.2.1  2006/02/05 23:38:08  thomson
+ * Devel branch with Temporary addresses support added.
+ *
  * Revision 1.3  2006/02/02 23:17:17  thomson
  * 0.4.2 release.
  *
@@ -23,18 +33,17 @@
 #include "DHCPConst.h"
 #include "SmartPtr.h"
 #include "Opt.h"
-
 class TClntConfMgr;
 
 class TOptOptionRequest : public TOpt
 {
   public:
     TOptOptionRequest(TMsg* parent);
-    TOptOptionRequest(char * &buf,  int &n, TMsg* parent);
+    TOptOptionRequest(char * &buf,  int &bufSize, TMsg* parent);
     
-    void addOption(short optNr);
-    void delOption(short optNr);
-    bool isOption(short optNr);
+    void addOption(unsigned short optNr);
+    void delOption(unsigned short optNr);
+    bool isOption(unsigned short optNr);
     int  count();
     void clearOptions();
 
@@ -45,7 +54,7 @@ class TOptOptionRequest : public TOpt
      ~TOptOptionRequest();	
   protected:
     bool Valid;
-    short *Options;
+    unsigned short *Options;
     int	OptCnt;
 };
 
