@@ -16,9 +16,9 @@
 class TOptVendorSpecInfo : public TOpt
 {
   public:
-    TOptVendorSpecInfo(int number, char * data, int dataLen);
-    TOptVendorSpecInfo( char * &buf,  int &n,TMsg* parent);
-    TOptVendorSpecInfo(int enterprise, char *data, int dataLen, TMsg* parent);
+//    TOptVendorSpecInfo(int type, int number, char * data, int dataLen);
+    TOptVendorSpecInfo(int type, char * &buf,  int &n,TMsg* parent);
+    TOptVendorSpecInfo(int type, int enterprise, char *data, int dataLen, TMsg* parent);
     int getSize();
     char * storeSelf( char* buf);
     bool isValid();
