@@ -6,9 +6,12 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: dibbler-server.cpp,v 1.18 2005-10-11 20:52:47 thomson Exp $
+ * $Id: dibbler-server.cpp,v 1.19 2008-06-01 21:45:48 thomson Exp $
  *
  * $Log: dibbler-server.cpp,v $
+ * Revision 1.19  2008-06-01 21:45:48  thomson
+ * Return coded are now returned properly under Linux (bug #175)
+ *
  * Revision 1.18  2005-10-11 20:52:47  thomson
  * Problem with command-line parsing fixed.
  *
@@ -95,6 +98,9 @@ int run() {
     TDHCPServer srv(SRVCONF_FILE);
     
     ptr = &srv;
+    if (ptr->isDone()) {
+	return -1;
+    }
     
     // connect signals
     signal(SIGTERM, signal_handler);
