@@ -11,7 +11,7 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: lowlevel-linux.c,v 1.8 2007-04-10 23:25:06 thomson Exp $
+ * $Id: lowlevel-linux.c,v 1.11 2008-06-22 11:43:18 thomson Exp $
  *
  */
 
@@ -23,6 +23,8 @@
 #include <netdb.h>
 #include <sys/socket.h>
 #include <sys/ioctl.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <linux/netdevice.h>
 #include <linux/if_arp.h>
 #include <linux/sockios.h>
@@ -33,6 +35,7 @@
 #include <time.h>
 #include <errno.h>
 
+
 #include "libnetlink.h"
 #include "ll_map.h"
 #include "utils.h"
@@ -604,6 +607,78 @@ int is_addr_tentative(char * ifacename, int iface, char * addr)
     return tentative;
 }
 
+uint32_t getAAASPIfromFile() {
+    char filename[1024];
+    struct stat st;
+    uint32_t ret;
+    FILE *file;
+
+    strcpy(filename, "/var/lib/dibbler/AAA/AAA-SPI");
+
+    if (stat(filename, &st))
+        return 0;
+
+    file = fopen(filename, "r");
+    if (!file)
+        return 0;
+
+    fscanf(file, "%x", &ret);
+    fclose(file);
+
+    return ret;
+}
+
+char * getAAAKeyFilename(uint32_t SPI)
+{
+    static char filename[1024];
+    if (SPI != 0)
+        snprintf(filename, 1024, "%s%s%x", "/var/lib/dibbler/AAA/", "AAA-key-", SPI);
+    else
+        strcpy(filename, "/var/lib/dibbler/AAA/AAA-key");
+    return filename;
+}
+
+char * getAAAKey(uint32_t SPI, unsigned *len) {
+    char * filename = 0;
+    struct stat st;
+    char * retval;
+    int offset = 0;
+    int fd;
+    int ret;
+
+    filename = getAAAKeyFilename(SPI);
+
+    if (stat(filename, &st))
+        return NULL;
+
+    fd = open(filename, O_RDONLY);
+    if (0 > fd)
+        return NULL;
+
+    /* FIXME should be freed somewhere */
+    retval = malloc(st.st_size);
+    if (!retval) {
+        close(fd);
+        return NULL;
+    }
+
+    while (offset < st.st_size) {
+        ret = read(fd, retval + offset, st.st_size - offset);
+        if (!ret) break;
+        if (ret < 0) {
+            return NULL;
+        }
+        offset += ret;
+    }
+    close(fd);
+
+    if (offset != st.st_size)
+        return NULL;
+
+    *len = st.st_size;
+    return retval;
+}
+
 char * error_message()
 {
     return Message;
@@ -633,3 +708,19 @@ char * _SL_;
 int dnet_pton(int af, const char *src, void *addr) { return 0; }
 const char *dnet_ntop(int af, const void *addr, char *str, size_t len){ return 0; }
 const char *ipx_ntop(int af, const void *addr, char *str, size_t len) { return 0; }
+
+#ifdef DEBUG
+#include <execinfo.h>
+
+/*
+  [Thomson: very clever function. It prints backtrace. Done by Michal Kowalczuk.]
+ */ 
+void print_trace(void)
+{
+  void *array[10];
+  size_t size;
+
+  size = backtrace (array, 10);
+  backtrace_symbols_fd (array, size, 1);
+}
+#endif
