@@ -6,10 +6,16 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: RelCfgIface.h,v 1.1 2005/01/11 22:53:35 thomson Exp $
+ * $Id: RelCfgIface.h,v 1.3 2007-05-01 12:03:13 thomson Exp $
  *
  * $Log: RelCfgIface.h,v $
- * Revision 1.1  2005/01/11 22:53:35  thomson
+ * Revision 1.3  2007-05-01 12:03:13  thomson
+ * Support for interface-id location added.
+ *
+ * Revision 1.2  2007-03-07 02:37:10  thomson
+ * Experimental support for guess-mode.
+ *
+ * Revision 1.1  2005-01-11 22:53:35  thomson
  * Relay skeleton implemented.
  *
  *
@@ -38,6 +44,7 @@ public:
     void setID(int ifaceID);
     int	getID();
     string getName();
+    string getFullName();
 
     SmartPtr<TIPv6Addr> getServerUnicast();
     SmartPtr<TIPv6Addr> getClientUnicast();
@@ -48,7 +55,7 @@ public:
     
     unsigned char getPreference();
     int getInterfaceID();
-
+    
 private:
     string Name;
     int	ID;
