@@ -6,9 +6,12 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: RelParsGlobalOpt.cpp,v 1.3 2007-05-01 12:03:13 thomson Exp $
+ * $Id: RelParsGlobalOpt.cpp,v 1.4 2008-03-02 19:35:26 thomson Exp $
  *
  * $Log: RelParsGlobalOpt.cpp,v $
+ * Revision 1.4  2008-03-02 19:35:26  thomson
+ * RemoteID, EchoRequest options implemented.
+ *
  * Revision 1.3  2007-05-01 12:03:13  thomson
  * Support for interface-id location added.
  *
@@ -56,3 +59,23 @@ void TRelParsGlobalOpt::setInterfaceIDOrder(ERelIfaceIdOrder order) {
 ERelIfaceIdOrder TRelParsGlobalOpt::getInterfaceIDOrder() {
     return InterfaceIDOrder;
 }
+
+void TRelParsGlobalOpt::setRemoteID(SPtr<TRelOptRemoteID> remoteID)
+{
+    RemoteID = remoteID;
+}
+
+SPtr<TRelOptRemoteID> TRelParsGlobalOpt::getRemoteID()
+{
+    return RemoteID;
+}
+
+void TRelParsGlobalOpt::setEcho(SPtr<TRelOptEcho> echo)
+{
+    Echo = echo;
+}
+
+SPtr<TRelOptEcho> TRelParsGlobalOpt::getEcho()
+{
+    return Echo;
+}
