@@ -6,11 +6,7 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: RelOptInterfaceID.cpp,v 1.1 2005/01/11 22:53:35 thomson Exp $
- *
- * $Log: RelOptInterfaceID.cpp,v $
- * Revision 1.1  2005/01/11 22:53:35  thomson
- * Relay skeleton implemented.
+ * $Id: RelOptInterfaceID.cpp,v 1.2 2006-10-29 13:11:46 thomson Exp $
  *
  */
 
@@ -18,13 +14,11 @@
 #include "DHCPConst.h"
 
 TRelOptInterfaceID::TRelOptInterfaceID(char * data, int dataLen, TMsg* parent)
-	:TOptInteger4(OPTION_INTERFACE_ID, data, dataLen, parent) {
-
+    :TOptInteger(OPTION_INTERFACE_ID, 4 /* FIXME: Support length other than 4 */, data, dataLen, parent) {
 }
 
 TRelOptInterfaceID::TRelOptInterfaceID(int interfaceID, TMsg* parent)
-    :TOptInteger4(OPTION_INTERFACE_ID, interfaceID, parent) {
-
+    :TOptInteger(OPTION_INTERFACE_ID, 4 /* FIXME: Support length other than 4 */, interfaceID, parent) {
 }
 
 bool TRelOptInterfaceID::doDuties() {
