@@ -6,7 +6,7 @@
  *                                                                           
  * released under GNU GPL v2 or later licence                                
  *                                                                           
- * $Id: SrvCfgIface.cpp,v 1.40 2007-05-03 23:16:29 thomson Exp $
+ * $Id: SrvCfgIface.cpp,v 1.43 2008-06-18 20:37:20 thomson Exp $
  */
 
 #include <cstdlib>
@@ -14,9 +14,12 @@
 #include "SrvCfgIface.h"
 #include "SrvCfgAddrClass.h"
 #include "SrvCfgPD.h"
-#include "DNSUpdate.h"
 #include "Logger.h"
 
+#ifndef MOD_SRV_DISABLE_DNSUPDATE
+#include "DNSUpdate.h"
+#endif
+
 using namespace std;
 
 void TSrvCfgIface::addClientExceptionsLst(List(TSrvCfgOptions) exLst)
@@ -25,16 +28,31 @@ void TSrvCfgIface::addClientExceptionsLst(List(TSrvCfgOptions) exLst)
     ExceptionsLst = exLst;
 }
 
-SPtr<TSrvCfgOptions> TSrvCfgIface::getClientException(SPtr<TDUID> duid, bool quiet)
+bool TSrvCfgIface::leaseQuerySupport()
+{
+    return LeaseQuery;
+}
+
+
+SPtr<TSrvCfgOptions> TSrvCfgIface::getClientException(SPtr<TDUID> duid, SPtr<TSrvOptRemoteID> remoteID, bool quiet)
 {
     SPtr<TSrvCfgOptions> x;
     ExceptionsLst.first();
     while (x=ExceptionsLst.get()) {
-	if (*(x->getDuid()) == *duid) {
+	if ( duid && x->getDuid() && (*(x->getDuid()) == *duid) ) {
 	    if (!quiet)
 		Log(Debug) << "Found per-client configuration (exception) for client with DUID=" << x->getDuid()->getPlain() << LogEnd;
 	    return x;
 	}
+	SPtr<TSrvOptRemoteID> id;
+	id = x->getRemoteID();
+
+	if ( remoteID && id && (remoteID->getVendor() == id->getVendor()) && (id->getVendorDataLen() == remoteID->getVendorDataLen())
+	     && !memcmp(id->getVendorData(), remoteID->getVendorData(), id->getVendorDataLen()) ) {
+		Log(Debug) << "Found per-client configuration (exception) for client with RemoteID: vendor=" << id->getVendor()
+			   << ", data=" << id->getVendorDataPlain() << "." << LogEnd;
+	    return x;
+	}
     }
     return 0;
 }
@@ -335,8 +353,10 @@ void TSrvCfgIface::setOptions(SmartPtr<TSrvParsGlobalOpt> opt) {
     this->ClntMaxLease  = opt->getClntMaxLease();
     this->RapidCommit   = opt->getRapidCommit();
     this->Unicast       = opt->getUnicast();
+    this->LeaseQuery    = opt->getLeaseQuerySupport();
     
     if (opt->supportFQDN()){
+#ifndef MOD_SRV_DISABLE_DNSUPDATE
 	this->setFQDNLst(opt->getFQDNLst());
 	this->setFQDNMode(opt->getFQDNMode());
 	this->setRevDNSZoneRootLength(opt->getRevDNSZoneRootLength());
@@ -351,8 +371,10 @@ void TSrvCfgIface::setOptions(SmartPtr<TSrvParsGlobalOpt> opt) {
 	    break;
 	case DNSUPDATE_MODE_BOTH:
 	    Log(Cont) << "server will perform both (AAAA and PTR) updates." << LogEnd;
-	    break;
 	}
+#else
+	Log(Error) << "DNSUpdate is disabled (please recompile)." << LogEnd;
+#endif
     	Log(Debug) <<"FQDN: revDNS zoneroot lenght set to " << this->getRevDNSZoneRootLength()<< "." << LogEnd;
     }
   
@@ -597,6 +619,7 @@ ostream& operator<<(ostream& out,TSrvCfgIface& iface) {
     out << "    <preference>" << (int)iface.preference << "</preference>" << std::endl;
     out << "    <ifaceMaxLease>" << iface.IfaceMaxLease << "</ifaceMaxLease>" << std::endl;
     out << "    <clntMaxLease>" << iface.ClntMaxLease << "</clntMaxLease>" << std::endl;
+    out << "    <LeaseQuery>" << (iface.LeaseQuery?"1":"0") << "</LeaseQuery>" << std::endl;
        
     if (iface.Unicast) {
         out << "    <unicast>" << *(iface.Unicast) << "</unicast>" << endl;
