@@ -4,10 +4,11 @@
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>                           
  *          Marek Senderski <msend@o2.pl>                                    
  * changes: Petr Pisar <petr.pisar(at)atlas(dot)cz>
+ *          Michal Kowalczuk <michal@kowalczuk.eu>
  *                                                                           
  * released under GNU GPL v2 or later licence                                
  *                                                                           
- * $Id: SrvCfgMgr.cpp,v 1.52 2007-09-07 08:31:19 thomson Exp $
+ * $Id: SrvCfgMgr.cpp,v 1.56 2008-06-02 00:15:01 thomson Exp $
  *
  */
 
@@ -54,6 +55,10 @@ TSrvCfgMgr::TSrvCfgMgr(SmartPtr<TSrvIfaceMgr> ifaceMgr, string cfgFile, string x
 
     this->dump();
 
+#ifndef MOD_DISABLE_AUTH
+    AuthKeys = new KeyList();
+#endif
+
     IsDone = false;
 }
 
@@ -85,7 +90,7 @@ bool TSrvCfgMgr::parseConfigFile(string cfgFile) {
     }
 
     // setup global options
-    this->setupGlobalOpts(parser.ParserOptStack.getLast());
+    this->setGlobalOptions(parser.ParserOptStack.getLast());
     
     // analyse interfaces mentioned in config file
     if (!this->matchParsedSystemInterfaces(&parser)) {
@@ -115,13 +120,20 @@ void TSrvCfgMgr::dump() {
     xmlDump.close();
 }
 
-bool TSrvCfgMgr::setupGlobalOpts(SmartPtr<TSrvParsGlobalOpt> opt) {
+bool TSrvCfgMgr::setGlobalOptions(SmartPtr<TSrvParsGlobalOpt> opt) {
     this->Workdir          = opt->getWorkDir();
     this->Stateless        = opt->getStateless();
     this->CacheSize        = opt->getCacheSize();
-    this->DigestLst        = opt->getDigest();
     this->InterfaceIDOrder = opt->getInterfaceIDOrder();
     this->InactiveMode     = opt->getInactiveMode(); // should the client accept not ready interfaces?
+    this->GuessMode        = opt->getGuessMode();
+
+#ifndef MOD_DISABLE_AUTH
+    this->DigestLst        = opt->getDigest();
+    this->AuthKeyGenNonceLen = opt->getAuthKeyLen();
+    this->AuthLifetime = opt->getAuthLifetime();
+#endif
+
     return true;
 }
 
@@ -672,6 +684,10 @@ bool TSrvCfgMgr::inactiveMode()
     return InactiveMode;
 }
 
+bool TSrvCfgMgr::guessMode()
+{
+    return GuessMode;
+}
 
 bool TSrvCfgMgr::setupRelay(SmartPtr<TSrvCfgIface> cfgIface) {
     SmartPtr<TIfaceIface> iface;
@@ -739,6 +755,34 @@ bool TSrvCfgMgr::incrPrefixCount(int ifindex, SPtr<TIPv6Addr> prefix)
     return iface->addClntPrefix(prefix);
 }
 
+#ifndef MOD_DISABLE_AUTH
+List(DigestTypes) TSrvCfgMgr::getDigestLst() {
+    return this->DigestLst;
+}
+
+enum DigestTypes TSrvCfgMgr::getDigest() {
+    SmartPtr<DigestTypes> dt;
+
+    if (0 == DigestLst.count())
+        return DIGEST_NONE;
+
+    dt = DigestLst.getFirst();
+    if (!dt || *dt >= DIGEST_INVALID)
+        return DIGEST_NONE;
+
+    return *dt;
+}
+
+unsigned int TSrvCfgMgr::getAuthLifetime()
+{
+    return AuthLifetime;
+}
+
+unsigned int TSrvCfgMgr::getAuthKeyGenNonceLen()
+{
+    return AuthKeyGenNonceLen;
+}
+#endif
 
 // --------------------------------------------------------------------
 // --- operators ------------------------------------------------------
@@ -750,6 +794,7 @@ ostream & operator<<(ostream &out, TSrvCfgMgr &x) {
     out << "  <LogName>" << x.getLogName()  << "</LogName>" << endl;
     out << "  <LogLevel>" << x.getLogLevel() << "</LogLevel>" << endl;
     out << "  <InactiveMode>" << (x.InactiveMode?1:0) << "</InactiveMode>" << endl;
+    out << "  <GuessMode>" << (x.GuessMode?1:0) << "</GuessMode>" << endl;
     if (x.DUID)
 	out << "  " << *x.DUID;
     else
@@ -772,6 +817,7 @@ ostream & operator<<(ostream &out, TSrvCfgMgr &x) {
     }
     out << "</InterfaceIDOrder>" << endl;
 
+#ifndef MOD_DISABLE_AUTH
     out << "  <auth count=\"" << x.DigestLst.count() << "\">";
     x.DigestLst.first();
     SPtr<DigestTypes> dig;
@@ -790,6 +836,7 @@ ostream & operator<<(ostream &out, TSrvCfgMgr &x) {
     }
 
     out << "</auth>" << endl;
+#endif
 
     if (x.stateless())
 	out << "  <stateless/>" << std::endl;
