@@ -3,10 +3,11 @@
  *                                                                           
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>                           
  *          Marek Senderski <msend@o2.pl>                                    
+ * changes: Michal Kowalczuk <michal@kowalczuk.eu>
  *                                                                           
  * released under GNU GPL v2 or later licence                                
  *                                                                           
- * $Id: SrvCfgMgr.h,v 1.18 2007-09-07 08:31:19 thomson Exp $
+ * $Id: SrvCfgMgr.h,v 1.22 2008-06-02 00:15:01 thomson Exp $
  *
  */
 
@@ -20,6 +21,7 @@ class TSrvCfgMgr;
 #include "DHCPConst.h"
 #include "Container.h"
 #include "DUID.h"
+#include "KeyList.h"
 
 #include "FlexLexer.h"
 #include "SrvParser.h"
@@ -69,15 +71,25 @@ public:
 
     bool isDone();
     virtual ~TSrvCfgMgr();
-    bool setupGlobalOpts(SmartPtr<TSrvParsGlobalOpt> opt);
+    bool setGlobalOptions(SmartPtr<TSrvParsGlobalOpt> opt);
 
     // configuration parameters
     string getWorkdir();
     bool stateless();
     bool inactiveMode();
+    bool guessMode();
     ESrvIfaceIdOrder getInterfaceIDOrder();
     int getCacheSize();
 
+    //Authentication
+#ifndef MOD_DISABLE_AUTH
+    SmartPtr<KeyList> AuthKeys;
+    unsigned int getAuthLifetime();
+    unsigned int getAuthKeyGenNonceLen();
+    List(DigestTypes) getDigestLst();
+    enum DigestTypes getDigest();
+#endif
+
 private:    
     static int NextRelayID;
     string XmlFile;
@@ -94,9 +106,15 @@ private:
     // global options
     bool Stateless;
     bool InactiveMode;
+    bool GuessMode;
     int  CacheSize;
-    List(DigestTypes) DigestLst;
     ESrvIfaceIdOrder InterfaceIDOrder;
+
+#ifndef MOD_DISABLE_AUTH
+    unsigned int AuthLifetime;
+    unsigned int AuthKeyGenNonceLen;
+    List(DigestTypes) DigestLst;
+#endif
 };
 
 #endif /* SRVCONFMGR_H */
