@@ -299,18 +299,31 @@ typedef
 #define	PD_LENGTH_	298
 #define	PD_POOL_	299
 #define	VENDOR_SPEC_	300
-#define	AUTH_	301
-#define	DIGEST_NONE_	302
-#define	DIGEST_HMAC_SHA1_	303
-#define	CLIENT_	304
-#define	INACTIVE_MODE_	305
-#define	EXPERIMENTAL_	306
-#define	ADDR_PARAMS_	307
-#define	STRING_	308
-#define	HEXNUMBER_	309
-#define	INTNUMBER_	310
-#define	IPV6ADDR_	311
-#define	DUID_	312
+#define	CLIENT_	301
+#define	DUID_KEYWORD_	302
+#define	REMOTE_ID_	303
+#define	ADDRESS_	304
+#define	GUESS_MODE_	305
+#define	INACTIVE_MODE_	306
+#define	EXPERIMENTAL_	307
+#define	ADDR_PARAMS_	308
+#define	AUTH_METHOD_	309
+#define	AUTH_LIFETIME_	310
+#define	AUTH_KEY_LEN_	311
+#define	DIGEST_NONE_	312
+#define	DIGEST_PLAIN_	313
+#define	DIGEST_HMAC_MD5_	314
+#define	DIGEST_HMAC_SHA1_	315
+#define	DIGEST_HMAC_SHA224_	316
+#define	DIGEST_HMAC_SHA256_	317
+#define	DIGEST_HMAC_SHA384_	318
+#define	DIGEST_HMAC_SHA512_	319
+#define	ACCEPT_LEASEQUERY_	320
+#define	STRING_	321
+#define	HEXNUMBER_	322
+#define	INTNUMBER_	323
+#define	IPV6ADDR_	324
+#define	DUID_	325
 
 
 #line 169 "../bison++/bison.h"
@@ -402,13 +415,26 @@ static const int PDCLASS_;
 static const int PD_LENGTH_;
 static const int PD_POOL_;
 static const int VENDOR_SPEC_;
-static const int AUTH_;
-static const int DIGEST_NONE_;
-static const int DIGEST_HMAC_SHA1_;
 static const int CLIENT_;
+static const int DUID_KEYWORD_;
+static const int REMOTE_ID_;
+static const int ADDRESS_;
+static const int GUESS_MODE_;
 static const int INACTIVE_MODE_;
 static const int EXPERIMENTAL_;
 static const int ADDR_PARAMS_;
+static const int AUTH_METHOD_;
+static const int AUTH_LIFETIME_;
+static const int AUTH_KEY_LEN_;
+static const int DIGEST_NONE_;
+static const int DIGEST_PLAIN_;
+static const int DIGEST_HMAC_MD5_;
+static const int DIGEST_HMAC_SHA1_;
+static const int DIGEST_HMAC_SHA224_;
+static const int DIGEST_HMAC_SHA256_;
+static const int DIGEST_HMAC_SHA384_;
+static const int DIGEST_HMAC_SHA512_;
+static const int ACCEPT_LEASEQUERY_;
 static const int STRING_;
 static const int HEXNUMBER_;
 static const int INTNUMBER_;
@@ -465,18 +491,31 @@ static const int DUID_;
 	,PD_LENGTH_=298
 	,PD_POOL_=299
 	,VENDOR_SPEC_=300
-	,AUTH_=301
-	,DIGEST_NONE_=302
-	,DIGEST_HMAC_SHA1_=303
-	,CLIENT_=304
-	,INACTIVE_MODE_=305
-	,EXPERIMENTAL_=306
-	,ADDR_PARAMS_=307
-	,STRING_=308
-	,HEXNUMBER_=309
-	,INTNUMBER_=310
-	,IPV6ADDR_=311
-	,DUID_=312
+	,CLIENT_=301
+	,DUID_KEYWORD_=302
+	,REMOTE_ID_=303
+	,ADDRESS_=304
+	,GUESS_MODE_=305
+	,INACTIVE_MODE_=306
+	,EXPERIMENTAL_=307
+	,ADDR_PARAMS_=308
+	,AUTH_METHOD_=309
+	,AUTH_LIFETIME_=310
+	,AUTH_KEY_LEN_=311
+	,DIGEST_NONE_=312
+	,DIGEST_PLAIN_=313
+	,DIGEST_HMAC_MD5_=314
+	,DIGEST_HMAC_SHA1_=315
+	,DIGEST_HMAC_SHA224_=316
+	,DIGEST_HMAC_SHA256_=317
+	,DIGEST_HMAC_SHA384_=318
+	,DIGEST_HMAC_SHA512_=319
+	,ACCEPT_LEASEQUERY_=320
+	,STRING_=321
+	,HEXNUMBER_=322
+	,INTNUMBER_=323
+	,IPV6ADDR_=324
+	,DUID_=325
 
 
 #line 215 "../bison++/bison.h"
