@@ -8,12 +8,10 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvIfaceMgr.cpp,v 1.25 2007-09-07 08:31:21 thomson Exp $
+ * $Id: SrvIfaceMgr.cpp,v 1.31 2008-06-18 23:22:15 thomson Exp $
  *
  */
 
-#include <malloc.h>
-#include <stdio.h>
 #include "Portable.h"
 #include "SmartPtr.h"
 #include "SrvIfaceMgr.h"
@@ -28,10 +26,13 @@
 #include "SrvMsgRelease.h"
 #include "SrvMsgDecline.h"
 #include "SrvMsgInfRequest.h"
+#include "SrvMsgLeaseQuery.h"
 #include "SrvOptInterfaceID.h"
 #include "IPv6Addr.h"
 #include "AddrClient.h"
 #include "SrvIfaceIface.h"
+#include "SrvOptEcho.h"
+#include "SrvOptGeneric.h"
 
 /**
  * ServerInterfaceManager - sends and receives messages (server version)
@@ -178,23 +179,31 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::select(unsigned long timeout) {
 	case RELEASE_MSG:
 	case DECLINE_MSG:
 	case INFORMATION_REQUEST_MSG:
+	case LEASEQUERY_MSG:
 	    ptr = this->decodeMsg(ptrIface, peer, buf, bufsize);
-        if (!ptr->validateAuthInfo(buf, bufsize))
+        if (!ptr->validateReplayDetection() ||
+            !ptr->validateAuthInfo(buf, bufsize)) {
+            Log(Error) << "Auth: Authorization failed, message dropped." << LogEnd;
             return 0;
+        }
         return ptr;
 	case RELAY_FORW_MSG:
 	    ptr = this->decodeRelayForw(ptrIface, peer, buf, bufsize);
-	if (!ptr)
-	    return 0;
-        if (!ptr->validateAuthInfo(buf, bufsize))
+        if (!ptr)
             return 0;
+        if (!ptr->validateReplayDetection() ||
+            !ptr->validateAuthInfo(buf, bufsize)) {
+            Log(Error) << "Auth: validation failed, message dropped." << LogEnd;
+            return 0;
+        }
         return ptr;
 	case ADVERTISE_MSG:
 	case REPLY_MSG:
 	case RECONFIGURE_MSG:
 	case RELAY_REPL_MSG:
+	case LEASEQUERY_REPLY_MSG:
 	    Log(Warning) << "Illegal message type " << msgtype << " received." << LogEnd;
-	    return 0; //NULL;;
+	    return 0; //NULL;
 	default:
 	    Log(Warning) << "Message type " << msgtype << " not supported. Ignoring." << LogEnd;
 	    return 0; //NULL
@@ -251,11 +260,18 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeRelayForw(SmartPtr<TSrvIfaceIface> ptrIfac
     SmartPtr<TIPv6Addr> peerAddrTbl[HOP_COUNT_LIMIT];
     SmartPtr<TSrvOptInterfaceID> interfaceIDTbl[HOP_COUNT_LIMIT];
     int hopTbl[HOP_COUNT_LIMIT];
+    List(TSrvOptGeneric) echoListTbl[HOP_COUNT_LIMIT];
     SmartPtr<TSrvIfaceIface> relayIface;
     int relays=0; // number of nested RELAY_FORW messages
+    SPtr<TSrvOptRemoteID> remoteID = 0;
+    SPtr<TSrvOptEcho> echo = 0;
+    SPtr<TSrvOptGeneric> gen = 0;
 
     char * relay_buf = buf;
-    int relay_bufsize = bufsize;    
+    int relay_bufsize = bufsize;
+
+    for (int j=0;j<HOP_COUNT_LIMIT; j++)
+	echoListTbl[j].clear();
 
     while (bufsize>0 && buf[0]==RELAY_FORW_MSG) {
 	/* decode RELAY_FORW message */
@@ -299,7 +315,7 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeRelayForw(SmartPtr<TSrvIfaceIface> ptrIfac
 				 << ") in RELAY_FORW message. Message dropped." << LogEnd;
 		    return 0;
 		}
-		ptrIfaceID = new TSrvOptInterfaceID(buf, bufsize, 0);
+		ptrIfaceID = new TSrvOptInterfaceID(buf, len, 0);
 		optIfaceIDCnt++;
 		break;
 	    case OPTION_RELAY_MSG:
@@ -307,13 +323,40 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeRelayForw(SmartPtr<TSrvIfaceIface> ptrIfac
 		relay_bufsize = len;
 		optRelayCnt++;
 		break;
+	    case OPTION_REMOTE_ID:
+		remoteID = new TSrvOptRemoteID(buf, len, 0);
+		break;
+	    case OPTION_ERO:
+		Log(Debug) << "Echo Request received in RELAY_FORW." << LogEnd;
+		echo = new TSrvOptEcho(buf, len, 0);
+		break;
 	    default:
-		Log(Warning) << "Invalid option (" << code << ") in RELAY_FORW message was ignored." << LogEnd;
+		gen = new TSrvOptGeneric(code, buf, len, 0);
+		echoListTbl[relays].append(gen);
+
 	    }
 	    buf     += len;
 	    bufsize -= len;
 	}
 
+	// remember options to be echoed
+	echoListTbl[relays].first();
+	while (gen = echoListTbl[relays].get()) {
+	    if (!echo) {
+		Log(Warning) << "Invalid option (" << gen->getOptType() << ") in RELAY_FORW message was ignored." << LogEnd;
+		echoListTbl[relays].del();
+	    } else {
+		if (!echo->isOption(gen->getOptType())) {
+		    Log(Warning) << "Invalid option (" << gen->getOptType() << ") in RELAY_FORW message was ignored." << LogEnd;
+		    echoListTbl[relays].del();
+		} else {
+		    Log(Info) << "Option " << gen->getOptType() << " will be echoed back." << LogEnd;
+		}
+	    }
+	    
+	}
+
+
 	// remember those links
 	linkAddrTbl[relays] = linkAddr;
 	peerAddrTbl[relays] = peerAddr;
@@ -338,15 +381,19 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeRelayForw(SmartPtr<TSrvIfaceIface> ptrIfac
 
 	Log(Info) << "RELAY_FORW was decapsulated: link=" << linkAddr->getPlain() << ", peer=" << peerAddr->getPlain();
 
+	bool guessMode = SrvCfgMgr->guessMode();
+
 	if (ptrIfaceID) {
 	    // find relay interface based on the interface-id option
 	    Log(Cont) << ", interfaceID=" << ptrIfaceID->getValue() << LogEnd;
 	    relayIface = ptrIface->getRelayByInterfaceID(ptrIfaceID->getValue());
 	    if (!relayIface) {
-		Log(Error) << "Unable to find relay interface with interfaceID=" << ptrIfaceID->getValue() << " defined on the " 
-			   << ptrIface->getName() << "/" << ptrIface->getID() << " interface." << LogEnd;
-		return 0;
-	    }
+	        if (!guessMode) {
+		    Log(Error) << "Unable to find relay interface with interfaceID=" << ptrIfaceID->getValue() << " defined on the " 
+			       << ptrIface->getName() << "/" << ptrIface->getID() << " interface." << LogEnd;
+		    return 0;
+		} 
+	    } 
 	}
 	else {
 	    // find relay interface based on the link address
@@ -356,20 +403,39 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeRelayForw(SmartPtr<TSrvIfaceIface> ptrIfac
 	    relayIface = ptrIface->getRelayByLinkAddr(linkAddr);
 	    if (!relayIface) {
 		Log(Error) << "Unable to find relay interface using link address: " << linkAddr->getPlain() << LogEnd;
-		return 0;
+		if (!guessMode) {
+		  return 0;
+		}
 	    }
 	}
+	if (!relayIface && guessMode) {
+	    relayIface = ptrIface->getAnyRelay();
+	    if (!relayIface) {
+	        Log(Error) << "Guess-mode: Unable to find any relays on " << ptrIface->getFullName() << LogEnd;
+	        return 0;
+	    }
+	    interfaceIDTbl[relays] = -1;
+	    Log(Notice) << "Guess-mode: Relayed interface guessed as " << relayIface->getFullName() << LogEnd;
+	}
+
 	// now switch to relay interface
 	ptrIface = relayIface;
 	buf = relay_buf;
 	bufsize = relay_bufsize;
     }
     
-    
     SmartPtr<TSrvMsg> msg = this->decodeMsg(ptrIface, peer, relay_buf, relay_bufsize);
     for (int i=0; i<relays; i++) {
-	msg->addRelayInfo(linkAddrTbl[i], peerAddrTbl[i], hopTbl[i], interfaceIDTbl[i]);
+	msg->addRelayInfo(linkAddrTbl[i], peerAddrTbl[i], hopTbl[i], interfaceIDTbl[i], echoListTbl[i]);
     }
+    if (remoteID) {
+	Log(Debug) << "RemoteID received: vendor=" << remoteID->getVendor() << ", length=" << remoteID->getVendorDataLen() << "." << LogEnd;
+	msg->setRemoteID(remoteID);
+	remoteID = 0;
+	remoteID = msg->getRemoteID();
+	PrintHex("RemoteID:", remoteID->getVendorData(), remoteID->getVendorDataLen());
+    }
+
     return (Ptr*)msg;
  }
 
@@ -412,6 +478,9 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeMsg(SmartPtr<TSrvIfaceIface> ptrIface,
 	return new TSrvMsgInfRequest(That, this->SrvTransMgr, 
 				     this->SrvCfgMgr, this->SrvAddrMgr,
 				     ifaceid, peer, buf, bufsize);
+    case LEASEQUERY_MSG:
+	return new TSrvMsgLeaseQuery(That, SrvCfgMgr, SrvAddrMgr, ifaceid, 
+				     peer, buf, bufsize);
     default:
 	Log(Warning) << "Illegal message type " << (int)(buf[0]) << " received." << LogEnd;
 	return 0; //NULL;;
