@@ -8,7 +8,7 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvMsg.cpp,v 1.45 2007-07-05 00:17:42 thomson Exp $
+ * $Id: SrvMsg.cpp,v 1.53 2008-06-18 20:38:26 thomson Exp $
  */
 
 #include <sstream>
@@ -31,6 +31,7 @@
 #include "SrvOptServerUnicast.h"
 #include "SrvOptStatusCode.h"
 #include "SrvOptRapidCommit.h"
+#include "SrvOptLQ.h"
 #include "SrvOptTA.h"
 #include "SrvCfgOptions.h"
 
@@ -47,8 +48,16 @@
 #include "SrvOptNISPServer.h"
 #include "SrvOptNISPDomain.h"
 #include "SrvOptLifetime.h"
+
+#ifndef MOD_SRV_DISABLE_DNSUPDATE
 #include "DNSUpdate.h"
+#endif
+
+#ifndef MOD_DISABLE_AUTH
+#include "SrvOptAAAAuthentication.h"
+#include "SrvOptKeyGeneration.h"
 #include "SrvOptAuthentication.h"
+#endif
 
 #include "Logger.h"
 #include "SrvIfaceMgr.h"
@@ -76,6 +85,12 @@ TSrvMsg::TSrvMsg(SmartPtr<TSrvIfaceMgr> IfaceMgr,
 {
     setAttribs(IfaceMgr,TransMgr,CfgMgr,AddrMgr);
     this->Relays = 0;
+
+
+#ifndef MOD_DISABLE_AUTH
+    this->DigestType = CfgMgr->getDigest();
+    this->AuthKeys = CfgMgr->AuthKeys;
+#endif
 }
 
 /** 
@@ -101,6 +116,11 @@ TSrvMsg::TSrvMsg(SmartPtr<TSrvIfaceMgr> IfaceMgr,
 {
     setAttribs(IfaceMgr,TransMgr,CfgMgr,AddrMgr);
     this->Relays = 0;
+
+#ifndef MOD_DISABLE_AUTH
+    this->AuthKeys = CfgMgr->AuthKeys;
+    this->DigestType = CfgMgr->getDigest();
+#endif
 	
     int pos=0;
     while (pos<bufSize)	{
@@ -204,17 +224,40 @@ TSrvMsg::TSrvMsg(SmartPtr<TSrvIfaceMgr> IfaceMgr,
 	case OPTION_IA_PD:
 	    ptr = new TSrvOptIA_PD(buf+pos, length, this);
 	    break;
-	case OPTION_AUTH:
-        this->DigestType = DIGEST_HMAC_SHA1;
-	    // FIXME: Detect digest type
-            this->DigestType = DIGEST_HMAC_SHA1;
-	    ptr = new TSrvOptAuthentication(buf+pos, length, this);
+	case OPTION_LQ_QUERY:
+	    ptr = new TSrvOptLQ(buf+pos, length, this);
 	    break;
+	    // remaining LQ options are not supported to be received by server
+
+#ifndef MOD_DISABLE_AUTH
+	case OPTION_AAAAUTH:
+	    if (SrvCfgMgr->getDigest() != DIGEST_NONE) {
+		this->DigestType = DIGEST_HMAC_SHA1;
+		ptr = new TSrvOptAAAAuthentication(buf+pos, length, this);
+	    }
+	    break;
+	case OPTION_KEYGEN:
+	    Log(Warning) << "Option OPTION_KEYGEN received by server is invalid, ignoring." << LogEnd;
+	    break;
+	case OPTION_AUTH:
+	    if (SrvCfgMgr->getDigest() != DIGEST_NONE) {
+		this->DigestType = SrvCfgMgr->getDigest();
+		
+		ptr = new TSrvOptAuthentication(buf+pos, length, this);
+		SmartPtr<TOptDUID> optDUID = (SmartPtr<TOptDUID>)this->getOption(OPTION_CLIENTID);
+		if (optDUID) {
+		    SmartPtr<TAddrClient> client = SrvAddrMgr->getClient(optDUID->getDUID());
+		    if (client)
+			client->setSPI(SPI);
+		}
+	    }
+#endif
+	    
+        break;
 	case OPTION_VENDOR_OPTS:
 	    ptr = new TSrvOptVendorSpec(buf+pos, length, this);
 	    break;
 	case OPTION_RECONF_ACCEPT:
-	  //this->DigestType = DIGEST_HMAC_SHA1;
 	case OPTION_USER_CLASS:
 	case OPTION_VENDOR_CLASS:
 	case OPTION_RECONF_MSG:
@@ -243,6 +286,8 @@ void TSrvMsg::setAttribs(SmartPtr<TSrvIfaceMgr> IfaceMgr,
     SrvAddrMgr=AddrMgr;
     FirstTimeStamp = now();
     this->MRT=0;
+    KeyGenNonce = NULL;
+    KeyGenNonceLen = 0;
 }
 
 void TSrvMsg::doDuties() {
@@ -260,11 +305,13 @@ unsigned long TSrvMsg::getTimeout() {
 void TSrvMsg::addRelayInfo(SmartPtr<TIPv6Addr> linkAddr,
 			   SmartPtr<TIPv6Addr> peerAddr,
 			   int hop,
-			   SmartPtr<TSrvOptInterfaceID> interfaceID) {
+			   SmartPtr<TSrvOptInterfaceID> interfaceID,
+                           List(TSrvOptGeneric) echolist) {
     this->LinkAddrTbl[this->Relays] = linkAddr;
     this->PeerAddrTbl[this->Relays] = peerAddr;
     this->HopTbl[this->Relays]      = hop;
     this->InterfaceIDTbl[this->Relays] = interfaceID;
+    this->EchoListTbl[this->Relays]    = echolist;
     this->Relays++;
 }
 
@@ -278,6 +325,7 @@ void TSrvMsg::send()
     int offset = 0;
     int port;
 
+    SPtr<TSrvOptGeneric> gen;
     SmartPtr<TSrvIfaceIface> ptrIface;
     SmartPtr<TSrvIfaceIface> under;
     ptrIface = (Ptr*) SrvIfaceMgr->getIfaceByID(this->Iface);
@@ -304,6 +352,12 @@ void TSrvMsg::send()
 	    len[i-1]= len[i] + 38; // 34 bytes (relay header) + 4 bytes (relay-msg option header)
 	    if (this->InterfaceIDTbl[i] && (SrvCfgMgr->getInterfaceIDOrder()!=SRV_IFACE_ID_ORDER_NONE)) {
 		len[i-1]+=this->InterfaceIDTbl[i]->getSize();
+
+		EchoListTbl[i].first();
+		while (gen = EchoListTbl[i].get()) {
+		    len[i-1] += gen->getSize();
+		}
+
 	    }
 	}
 
@@ -328,6 +382,10 @@ void TSrvMsg::send()
     this->SrvIfaceMgr->send(ptrIface->getID(), buf, offset, this->PeerAddr, port);
 }
 
+void TSrvMsg::copyRemoteID(SPtr<TSrvMsg> q) {
+  this->RemoteID = q->getRemoteID();
+}
+
 void TSrvMsg::copyRelayInfo(SmartPtr<TSrvMsg> q) {
     this->Relays = q->Relays;
     for (int i=0; i < this->Relays; i++) {
@@ -335,6 +393,7 @@ void TSrvMsg::copyRelayInfo(SmartPtr<TSrvMsg> q) {
 	this->PeerAddrTbl[i]   = q->PeerAddrTbl[i];
 	this->InterfaceIDTbl[i]= q->InterfaceIDTbl[i];
 	this->HopTbl[i]        = q->HopTbl[i];
+	this->EchoListTbl[i]   = q->EchoListTbl[i];
     }
 }
 
@@ -382,10 +441,62 @@ int TSrvMsg::storeSelfRelay(char * buf, int relayDepth, ESrvIfaceIdOrder order)
 	    offset += InterfaceIDTbl[relayDepth]->getSize();
 	}
     }
+
+    SPtr<TSrvOptGeneric> gen;
+    EchoListTbl[relayDepth].first();
+    while (gen = EchoListTbl[relayDepth].get()) {
+	Log(Debug) << "Echoing back option " << gen->getOptType() << ", length " << gen->getSize() << LogEnd;
+	gen->storeSelf(buf+offset);
+	offset += gen->getSize();
+    }
     
     return offset;
 }
 
+
+void TSrvMsg::copyAAASPI(SmartPtr<TSrvMsg> q) {
+#ifndef MOD_DISABLE_AUTH
+    this->AAASPI = q->getAAASPI();
+    this->SPI = q->getSPI();
+    this->AuthInfoKey = q->getAuthInfoKey();
+#endif
+}
+
+/** 
+ * this function appends authentication option
+ * 
+ */
+void TSrvMsg::appendAuthenticationOption(SmartPtr<TDUID> duid)
+{
+
+#ifndef MOD_DISABLE_AUTH
+    if (!duid) {
+        Log(Error) << "Auth: No duid! Probably internal error. Authentication option not appended." << LogEnd;
+        return;
+    }
+
+    DigestType = SrvCfgMgr->getDigest();
+    if (DigestType == DIGEST_NONE) {
+        // Log(Debug) << "Auth: Authentication is disabled." << LogEnd;
+        return;
+    }
+
+    Log(Debug) << "Auth: Setting DigestType to: " << this->DigestType << LogEnd;
+
+    if (!getOption(OPTION_AUTH)) {
+        SmartPtr<TAddrClient> client = SrvAddrMgr->getClient(duid);
+        if (client && !client->getSPI() && this->getSPI())
+            client->setSPI(this->getSPI());
+
+        if (client)
+            this->ReplayDetection = client->getNextReplayDetectionSent();
+        else
+            this->ReplayDetection = 1;
+        Options.append(new TSrvOptAuthentication(this));
+    }
+#endif
+}
+
 /** 
  * this function appends all standard options
  * 
@@ -410,7 +521,7 @@ bool TSrvMsg::appendRequestedOptions(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> a
 	return false;
     }
 
-    SPtr<TSrvCfgOptions> ex = ptrIface->getClientException(duid, false/* false = verbose */);
+    SPtr<TSrvCfgOptions> ex = ptrIface->getClientException(duid, getRemoteID(), false/* false = verbose */);
 
     // --- option: DNS resolvers ---
     if ( reqOpts->isOption(OPTION_DNS_SERVERS) && ptrIface->supportDNSServer() ) {
@@ -543,23 +654,14 @@ bool TSrvMsg::appendRequestedOptions(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> a
 	newOptionAssigned = true;
     }
 
-    // --- option: AUTH ---
-    // FIXME: implement some logic here
-    // if server is configured to allow DIGEST_NONE and client didn't send AUTH - don't send
-    // if server is configured to allow DIGEST_HMAC_SHA1 only, then send it
-    // FIXME: change to real DigestType
-    this->DigestType = DIGEST_HMAC_SHA1;
-    // if ...
-    // tips: use SrvCfgMgr->getDigest() 
-    if ( reqOpts->isOption(OPTION_AUTH) ) { 
-      // [s] - something like that has to be added'a: && ptrIface->supportLifetime() ) {
-      // [thomson] Note1: Sammael, don't use polish comments
-      // [thomson] Note2: supportLifetime() has nothing to do with AUTH
-      // FIXME: change to real DigestType
-	this->DigestType = DIGEST_HMAC_SHA1;
-	SmartPtr<TSrvOptAuthentication> optAuthentication = new TSrvOptAuthentication(this);
-	Options.append( (Ptr*)optAuthentication);
+    // --- option: KEYGEN ---
+#ifndef MOD_DISABLE_AUTH
+    if ( reqOpts->isOption(OPTION_KEYGEN) && SrvCfgMgr->getDigest() != DIGEST_NONE ) { // && this->MsgType == ADVERTISE_MSG ) {
+        	SmartPtr<TSrvOptKeyGeneration> optKeyGeneration = new TSrvOptKeyGeneration(this);
+        	Options.append( (Ptr*)optKeyGeneration);
     }
+#endif
+
 
     return newOptionAssigned;
 }
@@ -573,8 +675,6 @@ string TSrvMsg::showRequestedOptions(SmartPtr<TSrvOptOptionRequest> oro) {
     x << i << " opts";
     if (i)
 	x << ":";
-    // FIXME: change to real DigestType
-    this->DigestType = DIGEST_HMAC_SHA1;
     for (i=0;i<oro->count();i++) {
 	x << " " << oro->getReqOpt(i);
     }
@@ -699,7 +799,7 @@ SPtr<TSrvOptFQDN> TSrvMsg::prepareFQDN(SPtr<TSrvOptFQDN> requestFQDN, SPtr<TDUID
 	    DNSUpdate *act2 = new DNSUpdate(DNSAddr->getPlain(), "", fqdnName, IPv6Addr->getPlain(), DNSUPDATE_AAAA);
 	    result2 = act2->run();
 	    act2->showResult(result);
-	    delete act;
+	    delete act2;
 	} // fqdnMode == 2
 
 	// regardless of the result, store the info
@@ -829,3 +929,98 @@ bool TSrvMsg::appendVendorSpec(SPtr<TDUID> duid, int iface, int vendor, SPtr<TSr
     Log(Debug) << "Unable to find any vendor-specific option." << LogEnd;
     return false;
 }
+
+SmartPtr<TSrvTransMgr> TSrvMsg::getSrvTransMgr()
+{
+    return this->SrvTransMgr;
+}
+
+bool TSrvMsg::validateReplayDetection() {
+
+#ifndef MOD_DISABLE_AUTH
+    if (this->MsgType == SOLICIT_MSG)
+        return true;
+
+    if (SrvCfgMgr->getDigest() ==  DIGEST_NONE) {
+        // Log(Debug) << "Auth: Authentication is disabled." << LogEnd;
+        return true;
+    }
+
+    SmartPtr<TAddrClient> client = SrvAddrMgr->getClient(SPI);
+    if (!client) {
+        Log(Debug) << "Auth: Unable to find client with SPI=" << SPI << "." << LogEnd;
+        return true;
+    }
+
+    if (!client->getReplayDetectionRcvd() && !this->ReplayDetection)
+        return true;
+
+    if (client->getReplayDetectionRcvd() < this->ReplayDetection) {
+        client->setReplayDetectionRcvd(this->ReplayDetection);
+        return true;
+    } else {
+        Log(Warning) << "Auth: Replayed message detected, message dropped." << LogEnd;
+        return false;
+    }
+#else
+    return true;
+#endif
+}
+
+void TSrvMsg::setRemoteID(SPtr<TSrvOptRemoteID> remoteID)
+{
+    RemoteID = remoteID;
+}
+
+SPtr<TSrvOptRemoteID> TSrvMsg::getRemoteID()
+{
+    return RemoteID;
+}
+
+/** 
+ * copy status-code to top-level if something is wrong (i.e. status-code!=SUCCESS)
+ * 
+ */
+void TSrvMsg::appendStatusCode()
+{
+    SPtr<TSrvOptStatusCode> rootLevel, optLevel;
+    SPtr<TOpt> opt;
+    //rootLevel = getOption(OPTION_STATUS_CODE);
+
+    firstOption();
+    while (opt = getOption()) {
+	switch ( opt->getOptType() ) {
+	case OPTION_IA_NA:
+	{
+	    if (optLevel= (Ptr*)opt->getOption(OPTION_STATUS_CODE)) {
+		if (optLevel->getCode() != STATUSCODE_SUCCESS) {
+		    // copy status code to root-level
+		    delOption(OPTION_STATUS_CODE);
+		    rootLevel = new TSrvOptStatusCode(optLevel->getCode(), optLevel->getText(), this);
+		    Options.append( (Ptr*) rootLevel);
+		    return;
+		}
+	    }
+	}
+	default:
+	{
+
+	}
+	}
+	
+    }
+
+}
+
+bool TSrvMsg::delOption(int code)
+{
+    SPtr<TOpt> opt;
+    Options.first();
+    while (opt = Options.get()) {
+	if (opt->getOptType() == code) {
+	    Options.del();
+	    return true;
+	}
+    }
+    return false;
+}
