@@ -6,15 +6,7 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvMsgConfirm.h,v 1.3 2005/01/08 16:52:04 thomson Exp $
- *
- * $Log: SrvMsgConfirm.h,v $
- * Revision 1.3  2005/01/08 16:52:04  thomson
- * Relay support implemented.
- *
- * Revision 1.2  2004/06/20 17:25:07  thomson
- * getName() method implemented, clean up
- *
+ * $Id: SrvMsgConfirm.h,v 1.4 2006-08-21 21:33:20 thomson Exp $
  *
  */
 
@@ -39,13 +31,6 @@ class TSrvMsgConfirm : public TSrvMsg
 		   SmartPtr<TSrvAddrMgr> AddrMgr,
 		   int iface, SmartPtr<TIPv6Addr> addr,
 		   char* buf, int bufSize);
-    
-    TSrvMsgConfirm(SmartPtr<TSrvIfaceMgr> IfaceMgr, 
-		   SmartPtr<TSrvTransMgr> TransMgr, 
-		   SmartPtr<TSrvCfgMgr>	CfgMgr, 
-		   SmartPtr<TSrvAddrMgr> AddrMgr,
-		   int iface, SmartPtr<TIPv6Addr> addr);
-    
     bool check();
     void doDuties();
     unsigned long getTimeout();
