@@ -6,15 +6,7 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvMsgRebind.h,v 1.3 2005/01/08 16:52:04 thomson Exp $
- *
- * $Log: SrvMsgRebind.h,v $
- * Revision 1.3  2005/01/08 16:52:04  thomson
- * Relay support implemented.
- *
- * Revision 1.2  2004/06/20 17:25:07  thomson
- * getName() method implemented, clean up
- *
+ * $Id: SrvMsgRebind.h,v 1.4 2006-08-21 21:33:20 thomson Exp $
  *
  */
 
@@ -26,12 +18,6 @@ class TSrvMsgRebind;
 class TSrvMsgRebind : public TSrvMsg
 {
   public:
-    TSrvMsgRebind(SmartPtr<TSrvIfaceMgr>, 
-		  SmartPtr<TSrvTransMgr>, 
-		  SmartPtr<TSrvCfgMgr>, 
-		  SmartPtr<TSrvAddrMgr> AddrMgr,
-		  int iface,  SmartPtr<TIPv6Addr> addr);
-    
     TSrvMsgRebind(SmartPtr<TSrvIfaceMgr>, 
 		  SmartPtr<TSrvTransMgr>, 
 		  SmartPtr<TSrvCfgMgr>, 
