@@ -3,18 +3,10 @@
  *
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>
  *          Marek Senderski <msend@o2.pl>
- *
+ * chamges Krzysztof Wnuk <keczi@poczta.onet.pl>
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvMsgRenew.h,v 1.3 2005/01/08 16:52:04 thomson Exp $
- *
- * $Log: SrvMsgRenew.h,v $
- * Revision 1.3  2005/01/08 16:52:04  thomson
- * Relay support implemented.
- *
- * Revision 1.2  2004/06/20 17:25:07  thomson
- * getName() method implemented, clean up
- *
+ * $Id: SrvMsgRenew.h,v 1.5 2006-10-06 00:42:58 thomson Exp $
  *
  */
 
@@ -26,12 +18,6 @@ class TSrvMsgRenew;
 class TSrvMsgRenew : public TSrvMsg
 {
  public:
-    TSrvMsgRenew(SmartPtr<TSrvIfaceMgr> IfaceMgr,
-		 SmartPtr<TSrvTransMgr> TransMgr,
-		 SmartPtr<TSrvCfgMgr> CfgMgr,
-		 SmartPtr<TSrvAddrMgr> AddrMgr,
-		 int iface, SmartPtr<TIPv6Addr> addr);
-    
     TSrvMsgRenew(SmartPtr<TSrvIfaceMgr> IfaceMgr,SmartPtr<TSrvTransMgr> TransMgr,
 		 SmartPtr<TSrvCfgMgr> CfgMgr,SmartPtr<TSrvAddrMgr> AddrMgr,
 		 int iface, SmartPtr<TIPv6Addr> addr,
