@@ -3,6 +3,7 @@
  *
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>
  *          Marek Senderski <msend@o2.pl>
+ * changes: Michal Kowalczuk <michal@kowalczuk.eu>
  *
  * released under GNU GPL v2 or later licence
  *                                                                           
@@ -29,7 +30,10 @@
 #include "AddrIA.h"
 #include "AddrAddr.h"
 #include "Logger.h"
+
+#ifndef MOD_SRV_DISABLE_DNSUPDATE
 #include "DNSUpdate.h"
+#endif
 
 /** 
  * this constructor is used to create REPLY message as a response for CONFIRM message
@@ -50,6 +54,9 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
 	     confirm->getTransID())
 {
     this->copyRelayInfo((Ptr*)confirm);
+    this->copyAAASPI((Ptr*)confirm);
+    this->copyRemoteID((Ptr*)confirm);
+
     SmartPtr<TSrvCfgIface> ptrIface = CfgMgr->getIfaceByID( confirm->getIface() );
     if (!ptrIface) {
 	Log(Crit) << "Msg received through not configured interface. "
@@ -146,6 +153,10 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
 
     appendRequestedOptions(duidOpt->getDUID(), confirm->getAddr(), confirm->getIface(), reqOpts);
 
+    appendStatusCode();
+
+    appendAuthenticationOption(duidOpt->getDUID());
+
     pkt = new char[this->getSize()];
     IsDone = false;
     this->MRT = 31;
@@ -169,6 +180,9 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
 	     decline->getIface(),decline->getAddr(), REPLY_MSG, decline->getTransID())
 {
     this->copyRelayInfo((Ptr*)decline);
+    this->copyAAASPI((Ptr*)decline);
+    this->copyRemoteID((Ptr*)decline);
+
 
     SmartPtr<TOpt> ptrOpt;
 
@@ -268,6 +282,8 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
 	}
     }
 
+    appendAuthenticationOption(duidOpt->getDUID());
+
     pkt = new char[this->getSize()];
     IsDone = false;
     this->MRT = 31;
@@ -291,6 +307,8 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
 	     rebind->getIface(),rebind->getAddr(), REPLY_MSG, rebind->getTransID())
 {
     this->copyRelayInfo((Ptr*)rebind);
+    this->copyAAASPI((Ptr*)rebind);
+    this->copyRemoteID((Ptr*)rebind);
 
     unsigned long addrCount=0;
     SmartPtr<TOpt> ptrOpt;
@@ -350,6 +368,8 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
     SmartPtr<TSrvOptServerIdentifier> srvDUID=new TSrvOptServerIdentifier(CfgMgr->getDUID(),this);
     this->Options.append((Ptr*)srvDUID);
     
+    appendAuthenticationOption(duidOpt->getDUID());
+
     pkt = new char[this->getSize()];
     IsDone = false;
     this->MRT = 0;
@@ -376,6 +396,8 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
 	     release->getTransID())
 {
     this->copyRelayInfo((Ptr*)release);
+    this->copyAAASPI((Ptr*)release);
+    this->copyRemoteID((Ptr*)release);
 
      //FIXME:When the server receives a Release message via unicast from a client
     //to which the server has not sent a unicast option, the server
@@ -411,6 +433,8 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
 	return;
     }
 
+    appendAuthenticationOption(clntID->getDUID());
+
     release->firstOption();
     while(opt=release->getOption()) {
 	switch (opt->getOptType()) {
@@ -553,6 +577,9 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
 	     renew->getIface(),renew->getAddr(), REPLY_MSG, renew->getTransID())
 {
     this->copyRelayInfo((Ptr*)renew);
+    this->copyAAASPI((Ptr*)renew);
+    this->copyRemoteID((Ptr*)renew);
+
     // uncomment this to test REBIND
     //IsDone = true;
     //return;
@@ -611,6 +638,9 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
         }
     }
     appendRequestedOptions(duidOpt->getDUID(),renew->getAddr(),renew->getIface(),reqOpts);
+
+    appendAuthenticationOption(duidOpt->getDUID());
+
     pkt = new char[this->getSize()];
     IsDone = false;
     this->MRT = 0;
@@ -635,6 +665,8 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
 	     request->getIface(),request->getAddr(), REPLY_MSG, request->getTransID())
 {
     this->copyRelayInfo((Ptr*)request);
+    this->copyAAASPI((Ptr*)request);
+    this->copyRemoteID((Ptr*)request);
 
     SmartPtr<TOpt>       opt;
     SmartPtr<TSrvOptClientIdentifier> optClntID;
@@ -736,6 +768,9 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
     }
 
     appendRequestedOptions(clntDuid, clntAddr, clntIface, reqOpts);
+
+    appendAuthenticationOption(clntDuid);
+
     pkt = new char[this->getSize()];
     IsDone = false;
     SmartPtr<TIPv6Addr> ptrAddr;
@@ -753,6 +788,8 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
 	     solicit->getAddr(),REPLY_MSG,solicit->getTransID())
 {
     this->copyRelayInfo((Ptr*)solicit);
+    this->copyAAASPI((Ptr*)solicit);
+    this->copyRemoteID((Ptr*)solicit);
 
     SmartPtr<TOpt>       opt;
     SmartPtr<TSrvOptClientIdentifier> optClntID;
@@ -835,6 +872,8 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
     }
     appendRequestedOptions(clntDuid, clntAddr, clntIface, reqOpts);
 
+    appendAuthenticationOption(clntDuid);
+
     pkt = new char[this->getSize()];
     IsDone = false;
     SmartPtr<TIPv6Addr> ptrAddr;
@@ -852,6 +891,8 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
 	     question->getAddr(),REPLY_MSG,question->getTransID())
 {
     this->copyRelayInfo((Ptr*)question);
+    this->copyAAASPI((Ptr*)question);
+    this->copyRemoteID((Ptr*)question);
 
     SmartPtr<TOpt> ptrOpt;
     setOptionsReqOptClntDUID((Ptr*)question);
@@ -874,7 +915,8 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
             case OPTION_RECONF_MSG  :
             case OPTION_IA_NA       : 
             case OPTION_IA_TA       :
-            case OPTION_AUTH        :
+            case OPTION_AAAAUTH     :
+            case OPTION_KEYGEN      :
                 Log(Warning) << "Invalid option " << ptrOpt->getOptType() <<" received." << LogEnd;
                 break;
             default:
@@ -893,6 +935,8 @@ TSrvMsgReply::TSrvMsgReply(SmartPtr<TSrvIfaceMgr> ifaceMgr,
         SmartPtr<TSrvOptServerIdentifier> srvDUID=new TSrvOptServerIdentifier(CfgMgr->getDUID(),this);
         this->Options.append((Ptr*)srvDUID);
 
+        appendAuthenticationOption(duid);
+
         pkt = new char[this->getSize()];
         IsDone = false;
         this->MRT = 330; // FIXME: 
