@@ -6,15 +6,7 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvMsgSolicit.cpp,v 1.3 2005/01/08 16:52:04 thomson Exp $
- *
- * $Log: SrvMsgSolicit.cpp,v $
- * Revision 1.3  2005/01/08 16:52:04  thomson
- * Relay support implemented.
- *
- * Revision 1.2  2004/06/20 17:25:07  thomson
- * getName() method implemented, clean up
- *
+ * $Id: SrvMsgSolicit.cpp,v 1.5 2006-12-31 16:00:27 thomson Exp $
  *
  */
 
@@ -36,8 +28,7 @@ TSrvMsgSolicit::TSrvMsgSolicit(SmartPtr<TSrvIfaceMgr>	ifaceMgr,
 			       SmartPtr<TSrvAddrMgr>	addrMgr,
 			       int iface, SmartPtr<TIPv6Addr> addr,
 			       char* buf, int bufSize)
-    :TSrvMsg(ifaceMgr,transMgr,cfgMgr,addrMgr,iface,addr,buf,bufSize)
-{
+    :TSrvMsg(ifaceMgr,transMgr,cfgMgr,addrMgr,iface,addr,buf,bufSize) {
 }
 
 void TSrvMsgSolicit::doDuties() {
@@ -48,29 +39,14 @@ string TSrvMsgSolicit::getName() {
     return "SOLICIT";
 }
 
-bool TSrvMsgSolicit::check()
-{
-	SmartPtr<TOpt> option;
-	int cnt=0;
-	Options.first();
-	while (option = Options.get() ) 
-	{
-		if (option->getOptType() == OPTION_CLIENTID)
-			cnt++;
-		if (option->getOptType() == OPTION_SERVERID)
-			return false;
-	}
-		if (cnt!=1) return false;
-	return true;
+bool TSrvMsgSolicit::check() {
+    return TSrvMsg::check(true /* ClientID required */, false /* ServerID not allowed */);
 }
 
-unsigned long TSrvMsgSolicit::getTimeout()
-{
+unsigned long TSrvMsgSolicit::getTimeout() {
 	return 0;
 }
 
-TSrvMsgSolicit::~TSrvMsgSolicit()
-{
-	delete pkt;
-    pkt=NULL;
+TSrvMsgSolicit::~TSrvMsgSolicit() {
+
 }
