@@ -5,9 +5,13 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvOptAuthentication.cpp,v 1.1 2006-11-17 00:39:04 thomson Exp $
+ * $Id: SrvOptAuthentication.cpp,v 1.2 2008-02-25 17:49:12 thomson Exp $
  *
  * $Log: SrvOptAuthentication.cpp,v $
+ * Revision 1.2  2008-02-25 17:49:12  thomson
+ * Authentication added. Megapatch by Michal Kowalczuk.
+ * (small changes by Tomasz Mrugalski)
+ *
  * Revision 1.1  2006-11-17 00:39:04  thomson
  * Partial AUTH support by Sammael, fixes by thomson
  *
@@ -24,10 +28,9 @@ TSrvOptAuthentication::TSrvOptAuthentication(char * buf,  int n, TMsg* parent)
 	:TOptAuthentication(buf, n, parent) {
 }
 
-/* [s] - tu trzeba doda parametry opcji AUTH */
-//TSrvOptAuthentication::TSrvOptAuthentication(int status,string message, TMsg* parent)
-  TSrvOptAuthentication::TSrvOptAuthentication(TMsg* parent)
+TSrvOptAuthentication::TSrvOptAuthentication(TMsg* parent)
 	:TOptAuthentication(parent) {
+    setRDM(0);
 }
 
 bool TSrvOptAuthentication::doDuties()
