@@ -6,10 +6,13 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvOptDNSServers.cpp,v 1.3 2004/10/25 20:45:54 thomson Exp $
+ * $Id: SrvOptDNSServers.cpp,v 1.4 2007-01-21 19:17:58 thomson Exp $
  *
  * $Log: SrvOptDNSServers.cpp,v $
- * Revision 1.3  2004/10/25 20:45:54  thomson
+ * Revision 1.4  2007-01-21 19:17:58  thomson
+ * Option name constants updated (by Jyrki Soini)
+ *
+ * Revision 1.3  2004-10-25 20:45:54  thomson
  * Option support, parsers rewritten. ClntIfaceMgr now handles options.
  *
  */
@@ -18,12 +21,12 @@
 #include "DHCPConst.h"
 
 TSrvOptDNSServers::TSrvOptDNSServers(List(TIPv6Addr) lst, TMsg* parent)
-    :TOptAddrLst(OPTION_DNS_RESOLVERS, lst, parent) {
+    :TOptAddrLst(OPTION_DNS_SERVERS, lst, parent) {
 
 }
 
 TSrvOptDNSServers::TSrvOptDNSServers(char* buf, int size, TMsg* parent)
-    :TOptAddrLst(OPTION_DNS_RESOLVERS, buf,size, parent) {
+    :TOptAddrLst(OPTION_DNS_SERVERS, buf,size, parent) {
     
 }
 
