@@ -6,7 +6,7 @@
  *                                                                           
  * released under GNU GPL v2 or later licence                                
  *                                                                           
- * $Id: SrvOptIA_NA.cpp,v 1.24 2007-09-06 23:10:39 thomson Exp $
+ * $Id: SrvOptIA_NA.cpp,v 1.27 2008-06-01 18:29:04 thomson Exp $
  */
 
 #ifdef WIN32
@@ -20,6 +20,8 @@
 #include "SrvOptIAAddress.h"
 #include "SrvOptStatusCode.h"
 #include "SrvOptRapidCommit.h"
+#include "SrvOptRemoteID.h"
+#include "SrvCfgOptions.h"
 #include "Logger.h"
 #include "AddrClient.h"
 #include "DHCPConst.h"
@@ -110,7 +112,6 @@ TSrvOptIA_NA::TSrvOptIA_NA(SmartPtr<TSrvAddrMgr> addrMgr,  SmartPtr<TSrvCfgMgr>
     // FIXME: SOLICIT without RAPID COMMIT should set this to true
     bool quiet = false;
 
-
     // --- check if client already has binding
     if (renew(queryOpt, false)) {
       Log(Info) << "Previous binding for client " << ClntDuid->getPlain() << ", IA(iaid=" 
@@ -123,15 +124,27 @@ TSrvOptIA_NA::TSrvOptIA_NA(SmartPtr<TSrvAddrMgr> addrMgr,  SmartPtr<TSrvCfgMgr>
     if (!queryOpt->countAddrs()) {
       Log(Notice) << "IA option (with IAADDR suboptions missing) received. Assigning one address."
                   << LogEnd;
-      
-      SmartPtr<TIPv6Addr> anyaddr = new TIPv6Addr();
-      this->assignAddr(anyaddr, DHCPV6_INFINITY, DHCPV6_INFINITY, quiet);
-      
-      // include status code
+
+
+      // is there any specific address reserved for this client? (exception mechanism)
+      SPtr<TIPv6Addr> hint = getExceptionAddr();
+      if (!hint) {
+	  hint = new TIPv6Addr();
+      } else {
+	  Log(Notice) << "Reserved address " << hint->getPlain() << " for this client found, trying to assign." << LogEnd;
+      }
       SmartPtr<TSrvOptStatusCode> ptrStatus;
-      ptrStatus = new TSrvOptStatusCode(STATUSCODE_SUCCESS,
-                                        "1 addr granted. Next time you might consider including "
-                                        "IAADDR in IA option.",this->Parent);
+      if (this->assignAddr(hint, DHCPV6_INFINITY, DHCPV6_INFINITY, quiet))
+      {
+	  // include status code
+	  ptrStatus = new TSrvOptStatusCode(STATUSCODE_SUCCESS,
+					    "1 address granted. You may include IAADDR in IA option, if you want to provide a hint.",
+					    this->Parent);
+      } else {
+	  ptrStatus = new TSrvOptStatusCode(STATUSCODE_NOADDRSAVAIL,
+					    "No more addresses available. Sorry.",
+					    this->Parent);
+      }
       this->SubOptions.append((Ptr*)ptrStatus);
       
       return;
@@ -178,11 +191,20 @@ TSrvOptIA_NA::TSrvOptIA_NA(SmartPtr<TSrvAddrMgr> addrMgr,  SmartPtr<TSrvCfgMgr>
     queryOpt->firstOption();
     while ( opt = queryOpt->getOption() ) {
 	switch ( opt->getOptType() ) {
-      case OPTION_IAADDR: {
-      optAddr = (Ptr*) opt;
-      hint    = optAddr->getAddr();
-	  
-      if (willAssign) {
+	case OPTION_IAADDR: 
+	{
+	    optAddr = (Ptr*) opt;
+	    hint    = optAddr->getAddr();
+
+	    if (getExceptionAddr()) {
+		SPtr<TIPv6Addr> cliHint = hint;
+		hint = getExceptionAddr();
+		Log(Info) << "Client requested " << cliHint->getPlain();
+		Log(Cont) << ", but there is address reserved for this client: " << hint->getPlain() 
+			  << " (client's hint ignored)." << LogEnd;
+	    }
+	    
+	    if (willAssign) {
 		// we've got free addrs left, assign one of them
 		// always register this address as used by this client
 		// (if this is solicit, this addr will be released later)
@@ -191,24 +213,26 @@ TSrvOptIA_NA::TSrvOptIA_NA(SmartPtr<TSrvAddrMgr> addrMgr,  SmartPtr<TSrvCfgMgr>
 		this->assignAddr(hint, pref, valid, quiet);
 		willAssign--;
 		addrsAssigned++;
-        
-      } else {
+		
+	    } else {
 		ok = false;
-      }
-      break;
-      }
-      case OPTION_STATUS_CODE: {
+	    }
+	    break;
+	}
+	case OPTION_STATUS_CODE: 
+	{
 	    SmartPtr<TOptStatusCode> ptrStatus = (Ptr*) opt;
 	    Log(Notice) << "Receviced STATUS_CODE code=" 
-                    <<  ptrStatus->getCode() << ", message=(" << ptrStatus->getText()
-                    << ")" << LogEnd;
+			<<  ptrStatus->getCode() << ", message=(" << ptrStatus->getText()
+			<< ")" << LogEnd;
 	    break;
-      }
-      default: {
+	}
+	default: 
+	{
 	    Log(Warning) << "Invalid suboption (" << opt->getOptType() 
-                     << ") in an OPTION_IA_NA option received. Option ignored." << LogEnd;
+			 << ") in an OPTION_IA_NA option received. Option ignored." << LogEnd;
 	    break;
-      }
+	}
 	}
     }
     
@@ -259,6 +283,10 @@ SmartPtr<TSrvOptIAAddress> TSrvOptIA_NA::assignAddr(SmartPtr<TIPv6Addr> hint, un
     
     // get address
     addr = this->getFreeAddr(hint);
+    if (!addr) {
+	Log(Warning) << "There are no more addresses available." << LogEnd;
+	return 0;
+    }
     ptrClass = this->CfgMgr->getClassByAddr(this->Iface, addr);
     pref = ptrClass->getPref(pref);
     valid= ptrClass->getValid(valid);
@@ -284,6 +312,34 @@ SmartPtr<TSrvOptIAAddress> TSrvOptIA_NA::assignAddr(SmartPtr<TIPv6Addr> hint, un
     return optAddr;
 }
 
+/** 
+ * tries to find address reserved for this particular client
+ * 
+ * @return 
+ */
+SPtr<TIPv6Addr> TSrvOptIA_NA::getExceptionAddr()
+{
+    SmartPtr<TSrvCfgIface> ptrIface=CfgMgr->getIfaceByID(Iface);
+    if (!ptrIface) {
+	return 0;
+    }
+
+    SPtr<TSrvOptRemoteID> remoteID;
+
+
+    TSrvMsg * par = dynamic_cast<TSrvMsg*>(Parent);
+    if (par) {
+	remoteID = par->getRemoteID();
+    } else {
+    }
+
+    SPtr<TSrvCfgOptions> ex = ptrIface->getClientException(ClntDuid, remoteID, false/* false = verbose */);
+
+    if (ex)
+	return ex->getAddr();
+
+    return 0;
+}
 
 // constructor used only in RENEW, REBIND, DECLINE and RELEASE
 TSrvOptIA_NA::TSrvOptIA_NA( SmartPtr<TSrvCfgMgr> cfgMgr,
@@ -537,6 +593,7 @@ SmartPtr<TIPv6Addr> TSrvOptIA_NA::getFreeAddr(SmartPtr<TIPv6Addr> hint) {
 	    if (AddrMgr->addrIsFree(addr))
 		return addr;
 	    Log(Info) << "Unfortunately, " << addr->getPlain() << " is used." << LogEnd;
+	    AddrMgr->delCachedAddr(addr);
 	} else {
 	    Log(Warning) << "Cache: Cached address " << *addr << " found, but it is no longer valid." << LogEnd;
 	    AddrMgr->delCachedAddr(addr);
@@ -547,12 +604,24 @@ SmartPtr<TIPv6Addr> TSrvOptIA_NA::getFreeAddr(SmartPtr<TIPv6Addr> hint) {
     // or specified hint is invalid
     SmartPtr<TSrvCfgAddrClass> ptrClass;
     ptrClass = ptrIface->getRandomClass(this->ClntDuid, this->ClntAddr);
-    if (!ptrClass) {
+    if (!ptrClass || (ptrClass->getAssignedCount()>=ptrClass->getClassMaxLease()) ) {
+	// random class in invalid, let's try to find another one
+	
 	ptrIface->firstAddrClass();
-	ptrClass = ptrIface->getAddrClass();
+	while (ptrClass = ptrIface->getAddrClass()) {
+	    if (!ptrClass->clntSupported(ClntDuid, ClntAddr))
+		continue;
+	    if (ptrClass->getAssignedCount()>=ptrClass->getClassMaxLease())
+		continue;
+	    break;
+	}
+    }
+	
+    if (!ptrClass) {
+	Log(Warning) << "Unable to find any non-full class for this client." << LogEnd;
+	return 0;
     }
 
-    // FIXME: Check if there are any addresses available at all?
     do {
 	addr = ptrClass->getRandomAddr();
     } while (!AddrMgr->addrIsFree(hint));
