@@ -6,9 +6,12 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvOptIA_NA.h,v 1.9 2007-05-04 17:47:25 thomson Exp $
+ * $Id: SrvOptIA_NA.h,v 1.10 2008-03-02 19:20:30 thomson Exp $
  *
  * $Log: SrvOptIA_NA.h,v $
+ * Revision 1.10  2008-03-02 19:20:30  thomson
+ * RemoteID, EchoRequest options implemneted.
+ *
  * Revision 1.9  2007-05-04 17:47:25  thomson
  * *** empty log message ***
  *
@@ -89,7 +92,7 @@ class TSrvOptIA_NA : public TOptIA_NA
     SmartPtr<TSrvOptIAAddress> assignAddr(SmartPtr<TIPv6Addr> hint, unsigned long pref,
 					  unsigned long valid, bool quiet);
     SmartPtr<TIPv6Addr> getFreeAddr(SmartPtr<TIPv6Addr> hint);
-
+    SPtr<TIPv6Addr> getExceptionAddr();
 };
 
 #endif
