@@ -6,26 +6,20 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvOptLifetime.cpp,v 1.1 2004/11/02 01:30:54 thomson Exp $
+ * $Id: SrvOptLifetime.cpp,v 1.3 2007-01-21 19:17:58 thomson Exp $
  *
- * $Log: SrvOptLifetime.cpp,v $
- * Revision 1.1  2004/11/02 01:30:54  thomson
- * Initial version.
- *
- * Revision 1.2  2004/03/29 18:53:08  thomson
- * Author/Licence/cvs log/cvs version headers added.
  */
 
 #include "DHCPConst.h"
 #include "SrvOptLifetime.h"
 
 TSrvOptLifetime::TSrvOptLifetime(char * buf,  int n, TMsg* parent)
-	:TOptInteger4(OPTION_LIFETIME, buf,n, parent){
+	:TOptInteger(OPTION_INFORMATION_REFRESH_TIME, OPTION_INFORMATION_REFRESH_TIME_LEN, buf,n, parent){
 
 }
 
 TSrvOptLifetime::TSrvOptLifetime( unsigned int lifetime, TMsg* parent)
-	:TOptInteger4(OPTION_LIFETIME, lifetime, parent) {
+	:TOptInteger(OPTION_INFORMATION_REFRESH_TIME, OPTION_INFORMATION_REFRESH_TIME_LEN, lifetime, parent) {
 }
 
 bool TSrvOptLifetime::doDuties()
