@@ -6,10 +6,13 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvOptNTPServers.cpp,v 1.3 2004/10/25 20:45:54 thomson Exp $
+ * $Id: SrvOptNTPServers.cpp,v 1.4 2007-01-21 19:17:58 thomson Exp $
  *
  * $Log: SrvOptNTPServers.cpp,v $
- * Revision 1.3  2004/10/25 20:45:54  thomson
+ * Revision 1.4  2007-01-21 19:17:58  thomson
+ * Option name constants updated (by Jyrki Soini)
+ *
+ * Revision 1.3  2004-10-25 20:45:54  thomson
  * Option support, parsers rewritten. ClntIfaceMgr now handles options.
  *
  * Revision 1.2  2004/03/29 18:53:08  thomson
@@ -20,12 +23,12 @@
 #include "DHCPConst.h"
 
 TSrvOptNTPServers::TSrvOptNTPServers(List(TIPv6Addr) lst, TMsg* parent)
-    :TOptAddrLst(OPTION_NTP_SERVERS, lst, parent) {
+    :TOptAddrLst(OPTION_SNTP_SERVERS, lst, parent) {
 
 }
 
 TSrvOptNTPServers::TSrvOptNTPServers(char* buf, int size, TMsg* parent)
-    :TOptAddrLst(OPTION_NTP_SERVERS, buf, size, parent) {
+    :TOptAddrLst(OPTION_SNTP_SERVERS, buf, size, parent) {
     
 }
 
