@@ -6,10 +6,13 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvOptSIPDomain.cpp,v 1.1 2004/11/02 01:30:54 thomson Exp $
+ * $Id: SrvOptSIPDomain.cpp,v 1.2 2007-01-21 19:17:58 thomson Exp $
  *
  * $Log: SrvOptSIPDomain.cpp,v $
- * Revision 1.1  2004/11/02 01:30:54  thomson
+ * Revision 1.2  2007-01-21 19:17:58  thomson
+ * Option name constants updated (by Jyrki Soini)
+ *
+ * Revision 1.1  2004-11-02 01:30:54  thomson
  * Initial version.
  *
  * Revision 1.6  2004/09/07 17:42:31  thomson
@@ -23,11 +26,11 @@
 #include "DHCPConst.h"
 
 TSrvOptSIPDomain::TSrvOptSIPDomain(List(string) domains, TMsg* parent)    
-    :TOptStringLst(OPTION_SIP_DOMAINS, domains, parent) {
+    :TOptStringLst(OPTION_SIP_SERVER_D, domains, parent) {
 }
 
 TSrvOptSIPDomain::TSrvOptSIPDomain(char *buf, int bufsize, TMsg* parent)
-    :TOptStringLst(OPTION_SIP_DOMAINS, buf,bufsize, parent) {
+    :TOptStringLst(OPTION_SIP_SERVER_D, buf,bufsize, parent) {
 }
 
 bool TSrvOptSIPDomain::doDuties() {
