@@ -1,3 +1,4 @@
+
 /*
  * Dibbler - a portable DHCPv6
  *
@@ -7,7 +8,7 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvTransMgr.cpp,v 1.33 2007-09-07 08:31:21 thomson Exp $
+ * $Id: SrvTransMgr.cpp,v 1.36 2008-02-25 17:49:12 thomson Exp $
  *
  */
 
@@ -28,6 +29,8 @@
 #include "SrvMsgRebind.h"
 #include "SrvMsgRenew.h"
 #include "SrvMsgRelease.h"
+#include "SrvMsgLeaseQuery.h"
+#include "SrvMsgLeaseQueryReply.h"
 #include "SrvOptIA_NA.h"
 #include "SrvOptStatusCode.h"
 
@@ -247,6 +250,19 @@ void TSrvTransMgr::relayMsg(SmartPtr<TSrvMsg> msg)
 	MsgLst.append((Ptr*)answ);
 	break;
     }
+    case LEASEQUERY_MSG:
+    {
+	int iface = msg->getIface();
+	if (!CfgMgr->getIfaceByID(iface) || !CfgMgr->getIfaceByID(iface)->leaseQuerySupport()) {
+	    Log(Error) << "LQ: LeaseQuery message received on " << iface << " interface, but it is not supported there." << LogEnd;
+	    return;
+	}
+	Log(Debug) << "LQ: LeaseQuery received, preparing RQ_REPLY" << LogEnd;
+	SPtr<TSrvMsgLeaseQuery> lq = (Ptr*)msg;
+	answ = new TSrvMsgLeaseQueryReply(IfaceMgr, That, CfgMgr, AddrMgr, lq);
+	MsgLst.append( (Ptr*) answ);
+	break;
+    }
     case RECONFIGURE_MSG:
     case ADVERTISE_MSG:
     case REPLY_MSG: 
