@@ -6,27 +6,7 @@
  *
  * released under GNU GPL v2 or later licence
  *
- * $Id: SrvTransMgr.h,v 1.8 2005/02/01 00:57:36 thomson Exp $
- *
- * $Log: SrvTransMgr.h,v $
- * Revision 1.8  2005/02/01 00:57:36  thomson
- * no message
- *
- * Revision 1.7  2005/01/12 00:10:05  thomson
- * Compilation fixes.
- *
- * Revision 1.6  2005/01/08 16:52:04  thomson
- * Relay support implemented.
- *
- * Revision 1.5  2004/12/07 00:45:10  thomson
- * Manager creation unified and cleaned up.
- *
- * Revision 1.4  2004/09/05 15:27:49  thomson
- * Data receive switched from recvfrom to recvmsg, unicast partially supported.
- *
- * Revision 1.3  2004/09/03 20:58:36  thomson
- * *** empty log message ***
- *
+ * $Id: SrvTransMgr.h,v 1.10 2007-01-27 17:13:44 thomson Exp $
  *
  */
 
@@ -66,7 +46,7 @@ class TSrvTransMgr
     char * getCtrlAddr();
     int    getCtrlIface();
     
-    void setThat(SmartPtr<TSrvTransMgr> that);
+    void setContext(SmartPtr<TSrvTransMgr> transMgr);
   private:
     string XmlFile;
     List(TSrvMsg) MsgLst;
